# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SwapOptionV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _invalid_swap_outs: Optional[List[InvalidSwapOutV1]]
    _items_with_swap_pairs: Optional[List[ItemWithSwapPairsV1]]
    _swap_root_candidate: Optional[ItemPreviewWithAssetsV1]


    def __init__(
        self,
        invalid_swap_outs: Optional[List[InvalidSwapOutV1]] = None,
        items_with_swap_pairs: Optional[List[ItemWithSwapPairsV1]] = None,
        swap_root_candidate: Optional[ItemPreviewWithAssetsV1] = None,
    ) -> None: ...

    @property
    def invalid_swap_outs(self) -> Optional[List[InvalidSwapOutV1]]: ...

    @invalid_swap_outs.setter
    def invalid_swap_outs(self, invalid_swap_outs: Optional[List[InvalidSwapOutV1]]) -> None: ...

    @property
    def items_with_swap_pairs(self) -> Optional[List[ItemWithSwapPairsV1]]: ...

    @items_with_swap_pairs.setter
    def items_with_swap_pairs(self, items_with_swap_pairs: Optional[List[ItemWithSwapPairsV1]]) -> None: ...

    @property
    def swap_root_candidate(self) -> Optional[ItemPreviewWithAssetsV1]: ...

    @swap_root_candidate.setter
    def swap_root_candidate(self, swap_root_candidate: Optional[ItemPreviewWithAssetsV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AllContextOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _comments: List[ContextCommentOutputV1]
    _labels: List[ContextLabelOutputV1]
    _numerics: List[ContextNumericOutputV1]
    _opaque: List[ContextOpaqueOutputV1]


    def __init__(
        self,
        comments: Optional[List[ContextCommentOutputV1]] = None,
        labels: Optional[List[ContextLabelOutputV1]] = None,
        numerics: Optional[List[ContextNumericOutputV1]] = None,
        opaque: Optional[List[ContextOpaqueOutputV1]] = None,
    ) -> None: ...

    @property
    def comments(self) -> List[ContextCommentOutputV1]: ...

    @comments.setter
    def comments(self, comments: List[ContextCommentOutputV1]) -> None: ...

    @property
    def labels(self) -> List[ContextLabelOutputV1]: ...

    @labels.setter
    def labels(self, labels: List[ContextLabelOutputV1]) -> None: ...

    @property
    def numerics(self) -> List[ContextNumericOutputV1]: ...

    @numerics.setter
    def numerics(self, numerics: List[ContextNumericOutputV1]) -> None: ...

    @property
    def opaque(self) -> List[ContextOpaqueOutputV1]: ...

    @opaque.setter
    def opaque(self, opaque: List[ContextOpaqueOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ScheduleOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cron_schedule': 'str',
        'key': 'str',
        'stopped': 'bool'
    }

    attribute_map = {
        'cron_schedule': 'cronSchedule',
        'key': 'key',
        'stopped': 'stopped'
    }

    def __init__(self, cron_schedule=None, key=None, stopped=False):
        """
        ScheduleOutputV1 - a model defined in Swagger
        """

        self._cron_schedule = None
        self._key = None
        self._stopped = None

        if cron_schedule is not None:
          self.cron_schedule = cron_schedule
        if key is not None:
          self.key = key
        if stopped is not None:
          self.stopped = stopped

    @property
    def cron_schedule(self):
        """
        Gets the cron_schedule of this ScheduleOutputV1.
        The Notebook's run schedule as a cron expression (see http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :return: The cron_schedule of this ScheduleOutputV1.
        :rtype: str
        """
        return self._cron_schedule

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule):
        """
        Sets the cron_schedule of this ScheduleOutputV1.
        The Notebook's run schedule as a cron expression (see http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :param cron_schedule: The cron_schedule of this ScheduleOutputV1.
        :type: str
        """

        self._cron_schedule = cron_schedule

    @property
    def key(self):
        """
        Gets the key of this ScheduleOutputV1.
        The unique key of the schedule in the context of the Notebook-label combination

        :return: The key of this ScheduleOutputV1.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ScheduleOutputV1.
        The unique key of the schedule in the context of the Notebook-label combination

        :param key: The key of this ScheduleOutputV1.
        :type: str
        """

        self._key = key

    @property
    def stopped(self):
        """
        Gets the stopped of this ScheduleOutputV1.
        A boolean indicating whether the Notebook job has been deleted from the scheduler

        :return: The stopped of this ScheduleOutputV1.
        :rtype: bool
        """
        return self._stopped

    @stopped.setter
    def stopped(self, stopped):
        """
        Sets the stopped of this ScheduleOutputV1.
        A boolean indicating whether the Notebook job has been deleted from the scheduler

        :param stopped: The stopped of this ScheduleOutputV1.
        :type: bool
        """

        self._stopped = stopped

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ScheduleOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

__version__: str

# import apis into sdk package
from .api.access_keys_api import AccessKeysApi
from .api.add_ons_api import AddOnsApi
from .api.agents_api import AgentsApi
from .api.annotations_api import AnnotationsApi
from .api.applications_api import ApplicationsApi
from .api.assets_api import AssetsApi
from .api.audit_api import AuditApi
from .api.auth_api import AuthApi
from .api.boards_api import BoardsApi
from .api.cache_api import CacheApi
from .api.calculated_tables_api import CalculatedTablesApi
from .api.condition_monitors_api import ConditionMonitorsApi
from .api.conditions_api import ConditionsApi
from .api.content_api import ContentApi
from .api.context_api import ContextApi
from .api.custom_agents_api import CustomAgentsApi
from .api.datafiles_api import DatafilesApi
from .api.datasources_api import DatasourcesApi
from .api.display_templates_api import DisplayTemplatesApi
from .api.displays_api import DisplaysApi
from .api.export_api import ExportApi
from .api.folders_api import FoldersApi
from .api.formulas_api import FormulasApi
from .api.graph_ql_api import GraphQLApi
from .api.hierarchies_api import HierarchiesApi
from .api.items_api import ItemsApi
from .api.jobs_api import JobsApi
from .api.logs_api import LogsApi
from .api.markdown_items_api import MarkdownItemsApi
from .api.markdown_links_api import MarkdownLinksApi
from .api.materialized_tables_api import MaterializedTablesApi
from .api.metrics_api import MetricsApi
from .api.models_api import ModelsApi
from .api.monitors_api import MonitorsApi
from .api.networks_api import NetworksApi
from .api.notification_configurations_api import NotificationConfigurationsApi
from .api.notifier_api import NotifierApi
from .api.plugins_api import PluginsApi
from .api.projects_api import ProjectsApi
from .api.report_templates_api import ReportTemplatesApi
from .api.reports_api import ReportsApi
from .api.requests_api import RequestsApi
from .api.scim_api import SCIMApi
from .api.scalars_api import ScalarsApi
from .api.sharing_api import SharingApi
from .api.signal_monitors_api import SignalMonitorsApi
from .api.signals_api import SignalsApi
from .api.stored_tables_api import StoredTablesApi
from .api.subscriptions_api import SubscriptionsApi
from .api.system_api import SystemApi
from .api.table_definitions_api import TableDefinitionsApi
from .api.tables_api import TablesApi
from .api.trees_api import TreesApi
from .api.usage_api import UsageApi
from .api.user_groups_api import UserGroupsApi
from .api.users_api import UsersApi
from .api.workbooks_api import WorkbooksApi

# import models into sdk package
from .models.access_key_input_v1 import AccessKeyInputV1
from .models.access_key_output_list_v1 import AccessKeyOutputListV1
from .models.access_key_output_v1 import AccessKeyOutputV1
from .models.ace_input_v1 import AceInputV1
from .models.ace_output_v1 import AceOutputV1
from .models.acl_input_v1 import AclInputV1
from .models.acl_output_v1 import AclOutputV1
from .models.activity_graph_output_v1 import ActivityGraphOutputV1
from .models.activity_output_v1 import ActivityOutputV1
from .models.add_on_input_v1 import AddOnInputV1
from .models.add_on_output_list_v1 import AddOnOutputListV1
from .models.add_on_output_v1 import AddOnOutputV1
from .models.add_on_preview_output_list_v1 import AddOnPreviewOutputListV1
from .models.add_on_preview_v1 import AddOnPreviewV1
from .models.add_on_tool_input_v1 import AddOnToolInputV1
from .models.add_on_tool_output_v1 import AddOnToolOutputV1
from .models.administrator_contact_information_v1 import AdministratorContactInformationV1
from .models.agent_input_v1 import AgentInputV1
from .models.agent_key_output_v1 import AgentKeyOutputV1
from .models.agent_orchestrator_output_v1 import AgentOrchestratorOutputV1
from .models.agent_output_v1 import AgentOutputV1
from .models.agent_status_output_v1 import AgentStatusOutputV1
from .models.agent_status_v1 import AgentStatusV1
from .models.all_context_output_v1 import AllContextOutputV1
from .models.ancestor_filter_input_v1 import AncestorFilterInputV1
from .models.annotation_image_link_output_v1 import AnnotationImageLinkOutputV1
from .models.annotation_input_v1 import AnnotationInputV1
from .models.annotation_interest_input_v1 import AnnotationInterestInputV1
from .models.annotation_interest_output_v1 import AnnotationInterestOutputV1
from .models.annotation_list_output_v1 import AnnotationListOutputV1
from .models.annotation_output_v1 import AnnotationOutputV1
from .models.application_input_v1 import ApplicationInputV1
from .models.application_key_input_v1 import ApplicationKeyInputV1
from .models.application_output_v1 import ApplicationOutputV1
from .models.archive_output_v1 import ArchiveOutputV1
from .models.asset_batch_input_v1 import AssetBatchInputV1
from .models.asset_error import AssetError
from .models.asset_group_asset_input_v1 import AssetGroupAssetInputV1
from .models.asset_group_input_v1 import AssetGroupInputV1
from .models.asset_group_output_v1 import AssetGroupOutputV1
from .models.asset_group_root_input_v1 import AssetGroupRootInputV1
from .models.asset_group_tree_output_v1 import AssetGroupTreeOutputV1
from .models.asset_input_v1 import AssetInputV1
from .models.asset_output_v1 import AssetOutputV1
from .models.asset_selection_input_v1 import AssetSelectionInputV1
from .models.asset_selection_output_v1 import AssetSelectionOutputV1
from .models.asset_tree_batch_input_v1 import AssetTreeBatchInputV1
from .models.asset_tree_output_v1 import AssetTreeOutputV1
from .models.asset_tree_single_input_v1 import AssetTreeSingleInputV1
from .models.attachment_input_v1 import AttachmentInputV1
from .models.audit_output_list_v1 import AuditOutputListV1
from .models.audit_output_v1 import AuditOutputV1
from .models.auth_input_v1 import AuthInputV1
from .models.auth_providers_output_v1 import AuthProvidersOutputV1
from .models.authoritative_region_output_v1 import AuthoritativeRegionOutputV1
from .models.base_manual_run_input_v1 import BaseManualRunInputV1
from .models.base_output import BaseOutput
from .models.batch_archive_context_labels_input_v1 import BatchArchiveContextLabelsInputV1
from .models.board_create_input_v1 import BoardCreateInputV1
from .models.board_filter_create_input_v1 import BoardFilterCreateInputV1
from .models.board_filter_input_v1 import BoardFilterInputV1
from .models.board_filter_output_v1 import BoardFilterOutputV1
from .models.board_filter_update_input_v1 import BoardFilterUpdateInputV1
from .models.board_output_list_v1 import BoardOutputListV1
from .models.board_output_v1 import BoardOutputV1
from .models.board_tile_get_input_v1 import BoardTileGetInputV1
from .models.board_timeframe_comparison_input_v1 import BoardTimeframeComparisonInputV1
from .models.board_timeframe_comparison_metric_output_v1 import BoardTimeframeComparisonMetricOutputV1
from .models.board_timeframe_comparison_result_output_v1 import BoardTimeframeComparisonResultOutputV1
from .models.board_timeframe_comparison_tile_output_v1 import BoardTimeframeComparisonTileOutputV1
from .models.board_update_input_v1 import BoardUpdateInputV1
from .models.boolean_config_field_v1 import BooleanConfigFieldV1
from .models.cache_block import CacheBlock
from .models.cache_info_v1 import CacheInfoV1
from .models.calculated_item_output_v1 import CalculatedItemOutputV1
from .models.calculated_table_column_dependency_output_v1 import CalculatedTableColumnDependencyOutputV1
from .models.calculated_table_column_input_v1 import CalculatedTableColumnInputV1
from .models.calculated_table_column_metadata_output_v1 import CalculatedTableColumnMetadataOutputV1
from .models.calculated_table_data_query_input_v1 import CalculatedTableDataQueryInputV1
from .models.calculated_table_input_v1 import CalculatedTableInputV1
from .models.calculated_table_list_output_v1 import CalculatedTableListOutputV1
from .models.calculated_table_output_v1 import CalculatedTableOutputV1
from .models.capability_inheritance_output_v1 import CapabilityInheritanceOutputV1
from .models.capsule_event_input_v1 import CapsuleEventInputV1
from .models.capsule_input_v1 import CapsuleInputV1
from .models.capsule_property_input_v1 import CapsulePropertyInputV1
from .models.capsule_property_output_v1 import CapsulePropertyOutputV1
from .models.capsule_v1 import CapsuleV1
from .models.capsules_input_v1 import CapsulesInputV1
from .models.capsules_output_v1 import CapsulesOutputV1
from .models.capsules_overwrite_input_v1 import CapsulesOverwriteInputV1
from .models.category_label_pair_input_v1 import CategoryLabelPairInputV1
from .models.channel_output_v1 import ChannelOutputV1
from .models.chart_data_point_output_v1 import ChartDataPointOutputV1
from .models.chart_data_result_output_v1 import ChartDataResultOutputV1
from .models.column_data_update_input_list_v1 import ColumnDataUpdateInputListV1
from .models.column_data_update_input_v1 import ColumnDataUpdateInputV1
from .models.column_definition_bulk_edit_input_list_v1 import ColumnDefinitionBulkEditInputListV1
from .models.column_definition_bulk_edit_input_v1 import ColumnDefinitionBulkEditInputV1
from .models.column_definition_input_list_v1 import ColumnDefinitionInputListV1
from .models.column_definition_input_v1 import ColumnDefinitionInputV1
from .models.column_definition_order_input_v1 import ColumnDefinitionOrderInputV1
from .models.column_definition_output_v1 import ColumnDefinitionOutputV1
from .models.column_header_output_v1 import ColumnHeaderOutputV1
from .models.column_model_input_v1 import ColumnModelInputV1
from .models.column_model_output import ColumnModelOutput
from .models.column_override_input_list_v1 import ColumnOverrideInputListV1
from .models.column_override_input_v1 import ColumnOverrideInputV1
from .models.column_rule_ancestor_input_v1 import ColumnRuleAncestorInputV1
from .models.column_rule_asset_creator_input_v1 import ColumnRuleAssetCreatorInputV1
from .models.column_rule_concat_input_v1 import ColumnRuleConcatInputV1
from .models.column_rule_constant_input_v1 import ColumnRuleConstantInputV1
from .models.column_rule_context_condition_input_v1 import ColumnRuleContextConditionInputV1
from .models.column_rule_datasource_input_v1 import ColumnRuleDatasourceInputV1
from .models.column_rule_descendant_input_v1 import ColumnRuleDescendantInputV1
from .models.column_rule_descendant_search_input_v1 import ColumnRuleDescendantSearchInputV1
from .models.column_rule_event_asset_creator_input_v1 import ColumnRuleEventAssetCreatorInputV1
from .models.column_rule_event_property_input_v1 import ColumnRuleEventPropertyInputV1
from .models.column_rule_find_descendant_input_v1 import ColumnRuleFindDescendantInputV1
from .models.column_rule_find_property_input_v1 import ColumnRuleFindPropertyInputV1
from .models.column_rule_formula_creator_input_v1 import ColumnRuleFormulaCreatorInputV1
from .models.column_rule_get_item_property_input_v1 import ColumnRuleGetItemPropertyInputV1
from .models.column_rule_input_v1 import ColumnRuleInputV1
from .models.column_rule_item_search_input_v1 import ColumnRuleItemSearchInputV1
from .models.column_rule_item_type_input_v1 import ColumnRuleItemTypeInputV1
from .models.column_rule_manager_input_v1 import ColumnRuleManagerInputV1
from .models.column_rule_output_v1 import ColumnRuleOutputV1
from .models.column_rule_path_input_v1 import ColumnRulePathInputV1
from .models.column_rule_path_search_input_v1 import ColumnRulePathSearchInputV1
from .models.column_rule_preserve_existing_input_v1 import ColumnRulePreserveExistingInputV1
from .models.column_rule_scalar_creator_input_v1 import ColumnRuleScalarCreatorInputV1
from .models.column_rule_search_ancestor_input_v1 import ColumnRuleSearchAncestorInputV1
from .models.column_rule_set_item_property_input_v1 import ColumnRuleSetItemPropertyInputV1
from .models.column_rule_text_extractor_input_v1 import ColumnRuleTextExtractorInputV1
from .models.column_rule_text_replacement_input_v1 import ColumnRuleTextReplacementInputV1
from .models.column_rule_tree_path_creator_input_v1 import ColumnRuleTreePathCreatorInputV1
from .models.column_values_output_v1 import ColumnValuesOutputV1
from .models.comment_category_input_v1 import CommentCategoryInputV1
from .models.comment_category_output_list_v1 import CommentCategoryOutputListV1
from .models.comment_category_output_v1 import CommentCategoryOutputV1
from .models.complex_object_config_field_v1 import ComplexObjectConfigFieldV1
from .models.composite_filter import CompositeFilter
from .models.condition_batch_input_v1 import ConditionBatchInputV1
from .models.condition_input_v1 import ConditionInputV1
from .models.condition_monitor_input_v1 import ConditionMonitorInputV1
from .models.condition_monitor_metadata_output_list_v1 import ConditionMonitorMetadataOutputListV1
from .models.condition_monitor_metadata_output_v1 import ConditionMonitorMetadataOutputV1
from .models.condition_monitor_notification_configuration_input_v1 import ConditionMonitorNotificationConfigurationInputV1
from .models.condition_monitor_output_v1 import ConditionMonitorOutputV1
from .models.condition_monitor_workbook_output_v1 import ConditionMonitorWorkbookOutputV1
from .models.condition_output_v1 import ConditionOutputV1
from .models.condition_source_v1 import ConditionSourceV1
from .models.condition_table_input_v1 import ConditionTableInputV1
from .models.condition_table_stat_input_for_direct_items_v1 import ConditionTableStatInputForDirectItemsV1
from .models.condition_table_stat_input_for_table_v1 import ConditionTableStatInputForTableV1
from .models.condition_update_input_v1 import ConditionUpdateInputV1
from .models.config_field_v1 import ConfigFieldV1
from .models.configuration_input_v1 import ConfigurationInputV1
from .models.configuration_option_input_v1 import ConfigurationOptionInputV1
from .models.configuration_option_output_simple_v1 import ConfigurationOptionOutputSimpleV1
from .models.configuration_option_output_v1 import ConfigurationOptionOutputV1
from .models.configuration_output_v1 import ConfigurationOutputV1
from .models.configured_directives_output_v1 import ConfiguredDirectivesOutputV1
from .models.connection_input_v1 import ConnectionInputV1
from .models.connection_output_v1 import ConnectionOutputV1
from .models.connection_status_output_v1 import ConnectionStatusOutputV1
from .models.connection_status_v1 import ConnectionStatusV1
from .models.connections_output_v1 import ConnectionsOutputV1
from .models.connector_input_v1 import ConnectorInputV1
from .models.connector_output_v1 import ConnectorOutputV1
from .models.connectors_output_v1 import ConnectorsOutputV1
from .models.content_input_v1 import ContentInputV1
from .models.content_output_v1 import ContentOutputV1
from .models.content_with_metadata_list_output_v1 import ContentWithMetadataListOutputV1
from .models.content_with_metadata_output_v1 import ContentWithMetadataOutputV1
from .models.context_comment_input_v1 import ContextCommentInputV1
from .models.context_comment_list_output_v1 import ContextCommentListOutputV1
from .models.context_comment_output_v1 import ContextCommentOutputV1
from .models.context_condition_output_list_v1 import ContextConditionOutputListV1
from .models.context_condition_output_v1 import ContextConditionOutputV1
from .models.context_id_input_v1 import ContextIdInputV1
from .models.context_item import ContextItem
from .models.context_label_input_v1 import ContextLabelInputV1
from .models.context_label_list_output_v1 import ContextLabelListOutputV1
from .models.context_label_output_v1 import ContextLabelOutputV1
from .models.context_label_with_id_input_v1 import ContextLabelWithIdInputV1
from .models.context_numeric_input_v1 import ContextNumericInputV1
from .models.context_numeric_list_output_v1 import ContextNumericListOutputV1
from .models.context_numeric_output_v1 import ContextNumericOutputV1
from .models.context_opaque_input_v1 import ContextOpaqueInputV1
from .models.context_opaque_list_output_v1 import ContextOpaqueListOutputV1
from .models.context_opaque_output_v1 import ContextOpaqueOutputV1
from .models.context_permission_denied_output_v1 import ContextPermissionDeniedOutputV1
from .models.context_source_input_v1 import ContextSourceInputV1
from .models.context_source_output_v1 import ContextSourceOutputV1
from .models.context_user import ContextUser
from .models.csv_datafile_output_v1 import CsvDatafileOutputV1
from .models.cursor import Cursor
from .models.custom_agent_draft_create_input_v1 import CustomAgentDraftCreateInputV1
from .models.custom_agent_draft_info_output_v1 import CustomAgentDraftInfoOutputV1
from .models.custom_agent_draft_output_v1 import CustomAgentDraftOutputV1
from .models.custom_agent_draft_update_input_v1 import CustomAgentDraftUpdateInputV1
from .models.custom_agent_input_v1 import CustomAgentInputV1
from .models.custom_agent_meta_output_v1 import CustomAgentMetaOutputV1
from .models.custom_agent_metadata_update_input_v1 import CustomAgentMetadataUpdateInputV1
from .models.custom_agent_output_v1 import CustomAgentOutputV1
from .models.custom_agent_production_input_v1 import CustomAgentProductionInputV1
from .models.custom_agent_revision_output_v1 import CustomAgentRevisionOutputV1
from .models.custom_agent_summary_output_v1 import CustomAgentSummaryOutputV1
from .models.custom_agent_version_output_v1 import CustomAgentVersionOutputV1
from .models.datafile_input_v1 import DatafileInputV1
from .models.datafile_output_v1 import DatafileOutputV1
from .models.datafiles_csv_body import DatafilesCsvBody
from .models.datasource_access_stats_v1 import DatasourceAccessStatsV1
from .models.datasource_cache_clear_output_v1 import DatasourceCacheClearOutputV1
from .models.datasource_clean_up_input_v1 import DatasourceCleanUpInputV1
from .models.datasource_clean_up_output_v1 import DatasourceCleanUpOutputV1
from .models.datasource_input_v1 import DatasourceInputV1
from .models.datasource_output_list_v1 import DatasourceOutputListV1
from .models.datasource_output_v1 import DatasourceOutputV1
from .models.datasource_pair_output_v1 import DatasourcePairOutputV1
from .models.datasource_pairs_output_v1 import DatasourcePairsOutputV1
from .models.datasource_preview_v1 import DatasourcePreviewV1
from .models.datasource_statistics_v1 import DatasourceStatisticsV1
from .models.datasource_status_output_v1 import DatasourceStatusOutputV1
from .models.datasource_status_v1 import DatasourceStatusV1
from .models.datasource_summary_status_output_v1 import DatasourceSummaryStatusOutputV1
from .models.datasources_status_output_v1 import DatasourcesStatusOutputV1
from .models.date_range_input_v1 import DateRangeInputV1
from .models.date_range_output_v1 import DateRangeOutputV1
from .models.debug_cache_block_output_v1 import DebugCacheBlockOutputV1
from .models.delete_column_error_output_v1 import DeleteColumnErrorOutputV1
from .models.delete_result_output_v1 import DeleteResultOutputV1
from .models.delete_rows_input_v1 import DeleteRowsInputV1
from .models.delete_rows_output_v1 import DeleteRowsOutputV1
from .models.derived_feature_v1 import DerivedFeatureV1
from .models.detailed_meter_output_v1 import DetailedMeterOutputV1
from .models.detailed_timer_output_v1 import DetailedTimerOutputV1
from .models.direct_item_ids_source_v1 import DirectItemIdsSourceV1
from .models.directive_input_v1 import DirectiveInputV1
from .models.display_input_v1 import DisplayInputV1
from .models.display_output_list_v1 import DisplayOutputListV1
from .models.display_output_v1 import DisplayOutputV1
from .models.display_template_input_v1 import DisplayTemplateInputV1
from .models.display_template_output_list_v1 import DisplayTemplateOutputListV1
from .models.display_template_output_v1 import DisplayTemplateOutputV1
from .models.document_backup_output_v1 import DocumentBackupOutputV1
from .models.double_config_field_v1 import DoubleConfigFieldV1
from .models.duration_config_field_v1 import DurationConfigFieldV1
from .models.email_notification_recipient_output_v1 import EmailNotificationRecipientOutputV1
from .models.emailer_configuration_output_v1 import EmailerConfigurationOutputV1
from .models.enum_config_field_v1 import EnumConfigFieldV1
from .models.export_item_v1 import ExportItemV1
from .models.export_items_output_v1 import ExportItemsOutputV1
from .models.export_items_v1 import ExportItemsV1
from .models.export_preview_list_v1 import ExportPreviewListV1
from .models.export_preview_v1 import ExportPreviewV1
from .models.feature_argument_output_v1 import FeatureArgumentOutputV1
from .models.feature_output_v1 import FeatureOutputV1
from .models.feature_rule_v1 import FeatureRuleV1
from .models.feature_value_output_v1 import FeatureValueOutputV1
from .models.filter import Filter
from .models.fixed_list_filter_input_v1 import FixedListFilterInputV1
from .models.fixed_list_search_v1 import FixedListSearchV1
from .models.folded_stack_node_v1 import FoldedStackNodeV1
from .models.folder_input_v1 import FolderInputV1
from .models.folder_navigation_output_v1 import FolderNavigationOutputV1
from .models.folder_output_v1 import FolderOutputV1
from .models.folder_search_results_v1 import FolderSearchResultsV1
from .models.formula_compile_input_v1 import FormulaCompileInputV1
from .models.formula_compile_output_v1 import FormulaCompileOutputV1
from .models.formula_compiler_error_output_v1 import FormulaCompilerErrorOutputV1
from .models.formula_dependency_input_v1 import FormulaDependencyInputV1
from .models.formula_doc_example_input_v1 import FormulaDocExampleInputV1
from .models.formula_doc_example_list_input_v1 import FormulaDocExampleListInputV1
from .models.formula_doc_input_v1 import FormulaDocInputV1
from .models.formula_doc_keyword_list_input_v1 import FormulaDocKeywordListInputV1
from .models.formula_doc_output_v1 import FormulaDocOutputV1
from .models.formula_doc_summaries_output_v1 import FormulaDocSummariesOutputV1
from .models.formula_doc_summary_output_v1 import FormulaDocSummaryOutputV1
from .models.formula_error_output_v1 import FormulaErrorOutputV1
from .models.formula_example_output_v1 import FormulaExampleOutputV1
from .models.formula_generic_output_v1 import FormulaGenericOutputV1
from .models.formula_item_input_v1 import FormulaItemInputV1
from .models.formula_item_output_v1 import FormulaItemOutputV1
from .models.formula_log_entry import FormulaLogEntry
from .models.formula_log_entry_details import FormulaLogEntryDetails
from .models.formula_log_v1 import FormulaLogV1
from .models.formula_package_import_input_v1 import FormulaPackageImportInputV1
from .models.formula_package_import_output_v1 import FormulaPackageImportOutputV1
from .models.formula_package_input_v1 import FormulaPackageInputV1
from .models.formula_package_output_v1 import FormulaPackageOutputV1
from .models.formula_parameter_input_v1 import FormulaParameterInputV1
from .models.formula_parameter_output_v1 import FormulaParameterOutputV1
from .models.formula_run_input_v1 import FormulaRunInputV1
from .models.formula_run_output_v1 import FormulaRunOutputV1
from .models.formula_token import FormulaToken
from .models.formula_update_input_v1 import FormulaUpdateInputV1
from .models.formula_upgrade_change_v1 import FormulaUpgradeChangeV1
from .models.formula_upgrade_output_v1 import FormulaUpgradeOutputV1
from .models.function_input_v1 import FunctionInputV1
from .models.function_parameter_output_v1 import FunctionParameterOutputV1
from .models.function_variant_output_v1 import FunctionVariantOutputV1
from .models.gauge_datum_v1 import GaugeDatumV1
from .models.generate_chart_data_input_v1 import GenerateChartDataInputV1
from .models.generic_event_input_v1 import GenericEventInputV1
from .models.generic_table_output_v1 import GenericTableOutputV1
from .models.get_add_on_tools_output_v1 import GetAddOnToolsOutputV1
from .models.get_all_context_input_v1 import GetAllContextInputV1
from .models.get_applications_output_v1 import GetApplicationsOutputV1
from .models.get_channels_output_v1 import GetChannelsOutputV1
from .models.get_condition_monitor_items_output_v1 import GetConditionMonitorItemsOutputV1
from .models.get_content_items_output_v1 import GetContentItemsOutputV1
from .models.get_context_condition_input_v1 import GetContextConditionInputV1
from .models.get_context_input_v1 import GetContextInputV1
from .models.get_date_ranges_output_v1 import GetDateRangesOutputV1
from .models.get_jobs_output_v1 import GetJobsOutputV1
from .models.get_metrics_output_v1 import GetMetricsOutputV1
from .models.get_organizations_output_v1 import GetOrganizationsOutputV1
from .models.get_projects_output_v1 import GetProjectsOutputV1
from .models.get_request_output_v1 import GetRequestOutputV1
from .models.get_requests_output_v1 import GetRequestsOutputV1
from .models.get_sample_output_v1 import GetSampleOutputV1
from .models.get_samples_output_v1 import GetSamplesOutputV1
from .models.get_signal_monitor_items_output_v1 import GetSignalMonitorItemsOutputV1
from .models.get_signals_output_v1 import GetSignalsOutputV1
from .models.graph_ql_input_v1 import GraphQLInputV1
from .models.graph_ql_output_v1 import GraphQLOutputV1
from .models.group_by import GroupBy
from .models.group_value_column import GroupValueColumn
from .models.hierarchy_input_v1 import HierarchyInputV1
from .models.hierarchy_node_output_list_v1 import HierarchyNodeOutputListV1
from .models.hierarchy_node_output_v1 import HierarchyNodeOutputV1
from .models.hierarchy_node_with_path_output_v1 import HierarchyNodeWithPathOutputV1
from .models.hierarchy_output_list_v1 import HierarchyOutputListV1
from .models.hierarchy_output_v1 import HierarchyOutputV1
from .models.hierarchy_search_output_v1 import HierarchySearchOutputV1
from .models.hierarchy_search_v1 import HierarchySearchV1
from .models.hierarchy_validation_output_v1 import HierarchyValidationOutputV1
from .models.id_images_body import IdImagesBody
from .models.identity_mapping_list_v1 import IdentityMappingListV1
from .models.identity_mapping_v1 import IdentityMappingV1
from .models.identity_preview_list_v1 import IdentityPreviewListV1
from .models.identity_preview_v1 import IdentityPreviewV1
from .models.import_table_csv_output_v1 import ImportTableCSVOutputV1
from .models.indexing_parameters_input_v1 import IndexingParametersInputV1
from .models.input_feature_v1 import InputFeatureV1
from .models.installer_output_v1 import InstallerOutputV1
from .models.instance_output_mapping_v1 import InstanceOutputMappingV1
from .models.instance_output_paginated_list_v1 import InstanceOutputPaginatedListV1
from .models.instance_output_v1 import InstanceOutputV1
from .models.instance_retired_output_v1 import InstanceRetiredOutputV1
from .models.interval_v1 import IntervalV1
from .models.invalid_swap_out_v1 import InvalidSwapOutV1
from .models.issue_summary_output_v1 import IssueSummaryOutputV1
from .models.item_batch_output_v1 import ItemBatchOutputV1
from .models.item_dependency_output_v1 import ItemDependencyOutputV1
from .models.item_event_input_v1 import ItemEventInputV1
from .models.item_finder_input_v1 import ItemFinderInputV1
from .models.item_finder_output_list_v1 import ItemFinderOutputListV1
from .models.item_finder_output_v1 import ItemFinderOutputV1
from .models.item_finder_searches_input_v1 import ItemFinderSearchesInputV1
from .models.item_finder_searches_output_v1 import ItemFinderSearchesOutputV1
from .models.item_id_list_input_v1 import ItemIdListInputV1
from .models.item_metadata import ItemMetadata
from .models.item_output_v1 import ItemOutputV1
from .models.item_parameter_of_output_v1 import ItemParameterOfOutputV1
from .models.item_preview_list_v1 import ItemPreviewListV1
from .models.item_preview_v1 import ItemPreviewV1
from .models.item_preview_with_assets_v1 import ItemPreviewWithAssetsV1
from .models.item_search_input_v1 import ItemSearchInputV1
from .models.item_search_preview_list_v1 import ItemSearchPreviewListV1
from .models.item_search_preview_paginated_list_v1 import ItemSearchPreviewPaginatedListV1
from .models.item_search_preview_v1 import ItemSearchPreviewV1
from .models.item_swap_result_output_v1 import ItemSwapResultOutputV1
from .models.item_update_output_v1 import ItemUpdateOutputV1
from .models.item_user_attributes_input_v1 import ItemUserAttributesInputV1
from .models.item_user_attributes_output_v1 import ItemUserAttributesOutputV1
from .models.item_with_swap_pairs_v1 import ItemWithSwapPairsV1
from .models.jira_attachment import JiraAttachment
from .models.job_accepted_output_v1 import JobAcceptedOutputV1
from .models.job_output_v1 import JobOutputV1
from .models.join_input_v1 import JoinInputV1
from .models.json_backup_output_v1 import JsonBackupOutputV1
from .models.kpi_data_output_v1 import KpiDataOutputV1
from .models.label_category_input_v1 import LabelCategoryInputV1
from .models.label_category_output_list_v1 import LabelCategoryOutputListV1
from .models.label_category_output_v1 import LabelCategoryOutputV1
from .models.label_hierarchy_input_v1 import LabelHierarchyInputV1
from .models.label_hierarchy_output_list_v1 import LabelHierarchyOutputListV1
from .models.label_hierarchy_output_v1 import LabelHierarchyOutputV1
from .models.label_input_v1 import LabelInputV1
from .models.label_output_list_v1 import LabelOutputListV1
from .models.label_output_v1 import LabelOutputV1
from .models.last_run_state_output_v1 import LastRunStateOutputV1
from .models.license_importer_output_v1 import LicenseImporterOutputV1
from .models.license_status_output_v1 import LicenseStatusOutputV1
from .models.licensed_feature_status_output_v1 import LicensedFeatureStatusOutputV1
from .models.list_config_field_v1 import ListConfigFieldV1
from .models.lock_error_output_v1 import LockErrorOutputV1
from .models.lock_error_path_output_v1 import LockErrorPathOutputV1
from .models.lock_errors_output_v1 import LockErrorsOutputV1
from .models.lock_item_output_v1 import LockItemOutputV1
from .models.locked_item_list_output_v1 import LockedItemListOutputV1
from .models.log_message import LogMessage
from .models.log_message_input_v1 import LogMessageInputV1
from .models.log_message_output_v1 import LogMessageOutputV1
from .models.long_config_field_v1 import LongConfigFieldV1
from .models.manual_run_input_v1 import ManualRunInputV1
from .models.map_marker_rehydration_instructions_input_v1 import MapMarkerRehydrationInstructionsInputV1
from .models.map_marker_rehydration_instructions_output_v1 import MapMarkerRehydrationInstructionsOutputV1
from .models.markdown_item_input_v1 import MarkdownItemInputV1
from .models.markdown_item_list_v1 import MarkdownItemListV1
from .models.markdown_item_output_v1 import MarkdownItemOutputV1
from .models.markdown_link_upload_output_v1 import MarkdownLinkUploadOutputV1
from .models.markdown_links_body import MarkdownLinksBody
from .models.materialized_table_header_v1 import MaterializedTableHeaderV1
from .models.materialized_table_source_v1 import MaterializedTableSourceV1
from .models.materialized_table_v1 import MaterializedTableV1
from .models.media_type import MediaType
from .models.mention_input_v1 import MentionInputV1
from .models.meter_datum_v1 import MeterDatumV1
from .models.migrate_editor_input_v1 import MigrateEditorInputV1
from .models.model_application_error_output_v1 import ModelApplicationErrorOutputV1
from .models.model_application_mapping_v1 import ModelApplicationMappingV1
from .models.model_boolean_constant_rule_v1 import ModelBooleanConstantRuleV1
from .models.model_derived_column_names_input_v1 import ModelDerivedColumnNamesInputV1
from .models.model_draft_create_input_v1 import ModelDraftCreateInputV1
from .models.model_duplicate_input_v1 import ModelDuplicateInputV1
from .models.model_formula_creator_rule_v1 import ModelFormulaCreatorRuleV1
from .models.model_from_ids_input_v1 import ModelFromIdsInputV1
from .models.model_initial_application_input_v1 import ModelInitialApplicationInputV1
from .models.model_input_v1 import ModelInputV1
from .models.model_output_list_v1 import ModelOutputListV1
from .models.model_output_v1 import ModelOutputV1
from .models.model_publish_input_v1 import ModelPublishInputV1
from .models.model_reapplication_input_v1 import ModelReapplicationInputV1
from .models.model_rule_input_v1_list_string import ModelRuleInputV1ListString
from .models.model_rule_input_v1_object import ModelRuleInputV1Object
from .models.model_rule_input_v1_string import ModelRuleInputV1String
from .models.model_rule_input_v1_uuid import ModelRuleInputV1UUID
from .models.model_scalar_creator_rule_v1 import ModelScalarCreatorRuleV1
from .models.model_table_application_output_v1 import ModelTableApplicationOutputV1
from .models.model_table_applications_output_list_v1 import ModelTableApplicationsOutputListV1
from .models.model_table_applications_output_v1 import ModelTableApplicationsOutputV1
from .models.model_version_list_output_v1 import ModelVersionListOutputV1
from .models.model_version_output_v1 import ModelVersionOutputV1
from .models.monitor_definition_output_v1 import MonitorDefinitionOutputV1
from .models.monitor_definitions_output_v1 import MonitorDefinitionsOutputV1
from .models.monitor_input_v1 import MonitorInputV1
from .models.monitor_output_v1 import MonitorOutputV1
from .models.monitor_values import MonitorValues
from .models.monitored_condition_output_list_v1 import MonitoredConditionOutputListV1
from .models.monitored_condition_output_v1 import MonitoredConditionOutputV1
from .models.monitored_signal_last_run_state_output_v1 import MonitoredSignalLastRunStateOutputV1
from .models.monitored_signal_output_list_v1 import MonitoredSignalOutputListV1
from .models.monitored_signal_output_v1 import MonitoredSignalOutputV1
from .models.monitors_output_v1 import MonitorsOutputV1
from .models.node_path_input_v1 import NodePathInputV1
from .models.notifiable_report_output_list_v1 import NotifiableReportOutputListV1
from .models.notifiable_report_output_v1 import NotifiableReportOutputV1
from .models.notification_configuration_output_v1 import NotificationConfigurationOutputV1
from .models.numeric_description_input_v1 import NumericDescriptionInputV1
from .models.numeric_description_output_list_v1 import NumericDescriptionOutputListV1
from .models.numeric_description_output_v1 import NumericDescriptionOutputV1
from .models.optional_report_input_v1 import OptionalReportInputV1
from .models.order_by_input_v1 import OrderByInputV1
from .models.organization_input_v1 import OrganizationInputV1
from .models.organization_output_v1 import OrganizationOutputV1
from .models.parameter_doc_output_v1 import ParameterDocOutputV1
from .models.password_reset_input import PasswordResetInput
from .models.permissions_v1 import PermissionsV1
from .models.plugin_output_list_v1 import PluginOutputListV1
from .models.plugin_output_v1 import PluginOutputV1
from .models.plugins_body import PluginsBody
from .models.pre_cached_condition_capsule_property_info_v1 import PreCachedConditionCapsulePropertyInfoV1
from .models.pre_provision_input_v1 import PreProvisionInputV1
from .models.pre_provision_output_v1 import PreProvisionOutputV1
from .models.precached_item_output_v1 import PrecachedItemOutputV1
from .models.precached_items_output_v1 import PrecachedItemsOutputV1
from .models.priority_v1 import PriorityV1
from .models.progress_information_output_v1 import ProgressInformationOutputV1
from .models.project_input_v1 import ProjectInputV1
from .models.project_output_v1 import ProjectOutputV1
from .models.properties_for_item_uuid_column import PropertiesForItemUUIDColumn
from .models.properties_for_item_uuid_column_input_v1 import PropertiesForItemUUIDColumnInputV1
from .models.property_filter_input_v1 import PropertyFilterInputV1
from .models.property_href_output_v1 import PropertyHrefOutputV1
from .models.property_input_v1 import PropertyInputV1
from .models.property_output_v1 import PropertyOutputV1
from .models.property_search_v1 import PropertySearchV1
from .models.provision_input_v1 import ProvisionInputV1
from .models.publish_events_input_v1 import PublishEventsInputV1
from .models.publish_events_output_v1 import PublishEventsOutputV1
from .models.put_asset_input_v1 import PutAssetInputV1
from .models.put_scalar_input_v1 import PutScalarInputV1
from .models.put_scalars_input_v1 import PutScalarsInputV1
from .models.put_signals_input_v1 import PutSignalsInputV1
from .models.put_user_groups_input_v1 import PutUserGroupsInputV1
from .models.radial_gauge_rehydration_instructions_input_v1 import RadialGaugeRehydrationInstructionsInputV1
from .models.radial_gauge_rehydration_instructions_output_v1 import RadialGaugeRehydrationInstructionsOutputV1
from .models.radial_rehydration_instructions_input_v1 import RadialRehydrationInstructionsInputV1
from .models.radial_rehydration_instructions_output_v1 import RadialRehydrationInstructionsOutputV1
from .models.recompute_table_input_v1 import RecomputeTableInputV1
from .models.recompute_table_output_v1 import RecomputeTableOutputV1
from .models.referenced_input_item_v1 import ReferencedInputItemV1
from .models.referenced_items_output_v1 import ReferencedItemsOutputV1
from .models.referenced_output_item_v1 import ReferencedOutputItemV1
from .models.referenced_table_definition_ids_output_v1 import ReferencedTableDefinitionIdsOutputV1
from .models.regex_config_field_v1 import RegexConfigFieldV1
from .models.regression_output_v1 import RegressionOutputV1
from .models.rehydration_instructions_input_v1 import RehydrationInstructionsInputV1
from .models.rehydration_instructions_output_v1 import RehydrationInstructionsOutputV1
from .models.rehydration_series_lookup_input_v1 import RehydrationSeriesLookupInputV1
from .models.rehydration_series_lookup_output_v1 import RehydrationSeriesLookupOutputV1
from .models.release_notes_output_v1 import ReleaseNotesOutputV1
from .models.remote_agent_directives_output_v1 import RemoteAgentDirectivesOutputV1
from .models.remote_agent_status_input_v1 import RemoteAgentStatusInputV1
from .models.remote_agent_status_output_v1 import RemoteAgentStatusOutputV1
from .models.report_input_item_v1 import ReportInputItemV1
from .models.report_input_v1 import ReportInputV1
from .models.report_notification_configuration_input_v1 import ReportNotificationConfigurationInputV1
from .models.report_template_input_v1 import ReportTemplateInputV1
from .models.report_template_output_v1 import ReportTemplateOutputV1
from .models.request_output_v1 import RequestOutputV1
from .models.request_password_reset_input import RequestPasswordResetInput
from .models.row_event_input_v1 import RowEventInputV1
from .models.row_id import RowId
from .models.row_id_input_list_v1 import RowIdInputListV1
from .models.row_id_input_v1 import RowIdInputV1
from .models.row_rules_result_v1 import RowRulesResultV1
from .models.rules_result_message_v1 import RulesResultMessageV1
from .models.rules_result_v1 import RulesResultV1
from .models.run_condition_monitor_job_input_v1 import RunConditionMonitorJobInputV1
from .models.sample_input_v1 import SampleInputV1
from .models.sample_output_v1 import SampleOutputV1
from .models.samples_input_v1 import SamplesInputV1
from .models.samples_output_v1 import SamplesOutputV1
from .models.samples_overwrite_input_v1 import SamplesOverwriteInputV1
from .models.scalar_evaluate_output_v1 import ScalarEvaluateOutputV1
from .models.scalar_input_v1 import ScalarInputV1
from .models.scalar_property_v1 import ScalarPropertyV1
from .models.scalar_value_output_v1 import ScalarValueOutputV1
from .models.scale_across_tree_output_v1 import ScaleAcrossTreeOutputV1
from .models.scaling_table_uuid_column_search_v1 import ScalingTableUUIDColumnSearchV1
from .models.schedulable_admin_list_output_v1 import SchedulableAdminListOutputV1
from .models.schedulable_admin_output_v1 import SchedulableAdminOutputV1
from .models.schedulable_summary_day_output_v1 import SchedulableSummaryDayOutputV1
from .models.schedulable_summary_week_output_v1 import SchedulableSummaryWeekOutputV1
from .models.schedulable_workbook_output_v1 import SchedulableWorkbookOutputV1
from .models.schedule_input_v1 import ScheduleInputV1
from .models.schedule_output_v1 import ScheduleOutputV1
from .models.scheduled_notebook_input_v1 import ScheduledNotebookInputV1
from .models.scheduled_notebook_list_output_v1 import ScheduledNotebookListOutputV1
from .models.scheduled_notebook_output_v1 import ScheduledNotebookOutputV1
from .models.scheduled_notebook_result_input_v1 import ScheduledNotebookResultInputV1
from .models.scim_token_input_v1 import ScimTokenInputV1
from .models.scim_token_output_v1 import ScimTokenOutputV1
from .models.screenshot_output_v1 import ScreenshotOutputV1
from .models.secret_config_field_v1 import SecretConfigFieldV1
from .models.secret_status import SecretStatus
from .models.see_also_doc_output_v1 import SeeAlsoDocOutputV1
from .models.send_email_attachment_v1 import SendEmailAttachmentV1
from .models.send_email_contact_v1 import SendEmailContactV1
from .models.send_email_input_v1 import SendEmailInputV1
from .models.sent_email_attachment_output_v1 import SentEmailAttachmentOutputV1
from .models.sent_email_output_v1 import SentEmailOutputV1
from .models.sent_emails_list_output_v1 import SentEmailsListOutputV1
from .models.server_build_info_output_v1 import ServerBuildInfoOutputV1
from .models.server_load_output_v1 import ServerLoadOutputV1
from .models.server_spec_output_v1 import ServerSpecOutputV1
from .models.server_status_output_v1 import ServerStatusOutputV1
from .models.set_trust_input_v1 import SetTrustInputV1
from .models.shared_columns_output_v1 import SharedColumnsOutputV1
from .models.shared_item_information import SharedItemInformation
from .models.signal_input_v1 import SignalInputV1
from .models.signal_monitor_input_v1 import SignalMonitorInputV1
from .models.signal_monitor_metadata_output_list_v1 import SignalMonitorMetadataOutputListV1
from .models.signal_monitor_metadata_output_v1 import SignalMonitorMetadataOutputV1
from .models.signal_monitor_output_v1 import SignalMonitorOutputV1
from .models.signal_monitor_workbook_output_v1 import SignalMonitorWorkbookOutputV1
from .models.signal_output_v1 import SignalOutputV1
from .models.signal_with_id_input_v1 import SignalWithIdInputV1
from .models.simple_filter import SimpleFilter
from .models.sort import Sort
from .models.status_message import StatusMessage
from .models.status_message_base import StatusMessageBase
from .models.store_secret_input_v1 import StoreSecretInputV1
from .models.stored_table_csv_input_v1 import StoredTableCSVInputV1
from .models.stored_table_column_input_v1 import StoredTableColumnInputV1
from .models.stored_table_column_output_v1 import StoredTableColumnOutputV1
from .models.stored_table_delete_rows_input_v1 import StoredTableDeleteRowsInputV1
from .models.stored_table_output_v1 import StoredTableOutputV1
from .models.stored_table_search_failure_output_list_v1 import StoredTableSearchFailureOutputListV1
from .models.stored_table_search_failure_output_v1 import StoredTableSearchFailureOutputV1
from .models.stored_table_search_v1 import StoredTableSearchV1
from .models.storedtables_csv_body import StoredtablesCsvBody
from .models.string_config_field_v1 import StringConfigFieldV1
from .models.subscription_input_v1 import SubscriptionInputV1
from .models.subscription_output_v1 import SubscriptionOutputV1
from .models.subscription_update_input_v1 import SubscriptionUpdateInputV1
from .models.support_request_input_v1 import SupportRequestInputV1
from .models.support_request_output_v1 import SupportRequestOutputV1
from .models.supported_units_output_v1 import SupportedUnitsOutputV1
from .models.suppress_condition_input_v1 import SuppressConditionInputV1
from .models.suppressed_condition_input_v1 import SuppressedConditionInputV1
from .models.suppressed_condition_output_v1 import SuppressedConditionOutputV1
from .models.swap_across_assets_search_v1 import SwapAcrossAssetsSearchV1
from .models.swap_input_v1 import SwapInputV1
from .models.swap_option_list_v1 import SwapOptionListV1
from .models.swap_option_v1 import SwapOptionV1
from .models.swap_output_v1 import SwapOutputV1
from .models.sync_progress import SyncProgress
from .models.sync_progress_output_v1 import SyncProgressOutputV1
from .models.system_license_body import SystemLicenseBody
from .models.table_application_retired_output_v1 import TableApplicationRetiredOutputV1
from .models.table_column_output_v1 import TableColumnOutputV1
from .models.table_compute_output_v1 import TableComputeOutputV1
from .models.table_data_query_input_v1 import TableDataQueryInputV1
from .models.table_definition_csv_input_v1 import TableDefinitionCSVInputV1
from .models.table_definition_csv_publish_rows_input_v1 import TableDefinitionCSVPublishRowsInputV1
from .models.table_definition_csv_publish_rows_output_v1 import TableDefinitionCSVPublishRowsOutputV1
from .models.table_definition_csv_update_input_v1 import TableDefinitionCSVUpdateInputV1
from .models.table_definition_input_v1 import TableDefinitionInputV1
from .models.table_definition_metadata_output_v1 import TableDefinitionMetadataOutputV1
from .models.table_definition_output_list_v1 import TableDefinitionOutputListV1
from .models.table_definition_output_v1 import TableDefinitionOutputV1
from .models.table_definition_preview_input_v1 import TableDefinitionPreviewInputV1
from .models.table_definition_preview_output_v1 import TableDefinitionPreviewOutputV1
from .models.table_definition_update_input_v1 import TableDefinitionUpdateInputV1
from .models.table_formula import TableFormula
from .models.table_join_input import TableJoinInput
from .models.table_model_application_input_v1 import TableModelApplicationInputV1
from .models.table_property_filter_input_v1 import TablePropertyFilterInputV1
from .models.table_property_input_v1 import TablePropertyInputV1
from .models.table_result_output_v1 import TableResultOutputV1
from .models.tabledefinitions_csv_body import TabledefinitionsCsvBody
from .models.threshold_metric_input_v1 import ThresholdMetricInputV1
from .models.threshold_metric_output_v1 import ThresholdMetricOutputV1
from .models.threshold_output_v1 import ThresholdOutputV1
from .models.tile_create_input_v1 import TileCreateInputV1
from .models.tile_layout_output_v1 import TileLayoutOutputV1
from .models.tile_output_v1 import TileOutputV1
from .models.tile_update_input_v1 import TileUpdateInputV1
from .models.time_interval import TimeInterval
from .models.timer_datum_v1 import TimerDatumV1
from .models.topic_sandbox_input_v1 import TopicSandboxInputV1
from .models.tree_item_output_v1 import TreeItemOutputV1
from .models.treemap_item_output_v1 import TreemapItemOutputV1
from .models.treemap_output_v1 import TreemapOutputV1
from .models.units_of_measure_batch_input_v1 import UnitsOfMeasureBatchInputV1
from .models.units_of_measure_item_v1 import UnitsOfMeasureItemV1
from .models.units_of_measure_output_v1 import UnitsOfMeasureOutputV1
from .models.unsubscribe_output_v1 import UnsubscribeOutputV1
from .models.updated_rows_output_v1 import UpdatedRowsOutputV1
from .models.usage_output_list_v1 import UsageOutputListV1
from .models.usage_output_v1 import UsageOutputV1
from .models.usage_types_v1 import UsageTypesV1
from .models.user_group_input_v1 import UserGroupInputV1
from .models.user_group_output_v1 import UserGroupOutputV1
from .models.user_group_with_id_input_v1 import UserGroupWithIdInputV1
from .models.user_input_v1 import UserInputV1
from .models.user_output_list_v1 import UserOutputListV1
from .models.user_output_v1 import UserOutputV1
from .models.user_password_input_v1 import UserPasswordInputV1
from .models.validate_cron_list_input_v1 import ValidateCronListInputV1
from .models.validate_cron_list_output_v1 import ValidateCronListOutputV1
from .models.validate_cron_output_v1 import ValidateCronOutputV1
from .models.value import Value
from .models.value_filter import ValueFilter
from .models.version_history_output_list_v1 import VersionHistoryOutputListV1
from .models.version_history_output_v1 import VersionHistoryOutputV1
from .models.version_input_v1 import VersionInputV1
from .models.version_output_v1 import VersionOutputV1
from .models.version_source_item_output_v1 import VersionSourceItemOutputV1
from .models.version_source_output_v1 import VersionSourceOutputV1
from .models.view_column_filter_input_v1 import ViewColumnFilterInputV1
from .models.view_column_filter_output_v1 import ViewColumnFilterOutputV1
from .models.view_column_input_v1 import ViewColumnInputV1
from .models.view_column_output_v1 import ViewColumnOutputV1
from .models.virtual_columns import VirtualColumns
from .models.workbench_item_output_list_v1 import WorkbenchItemOutputListV1
from .models.workbench_search_result_preview_v1 import WorkbenchSearchResultPreviewV1
from .models.workbook_input_v1 import WorkbookInputV1
from .models.workbook_output_list_v1 import WorkbookOutputListV1
from .models.workbook_output_v1 import WorkbookOutputV1
from .models.workbook_owner_output_v1 import WorkbookOwnerOutputV1
from .models.worksheet_input_v1 import WorksheetInputV1
from .models.worksheet_output_list_v1 import WorksheetOutputListV1
from .models.worksheet_output_v1 import WorksheetOutputV1
from .models.workstep_chronology_entry_v1 import WorkstepChronologyEntryV1
from .models.workstep_chronology_output_v1 import WorkstepChronologyOutputV1
from .models.workstep_input_v1 import WorkstepInputV1
from .models.workstep_output_v1 import WorkstepOutputV1

from .api_client import ApiClient

from .configuration import Configuration

configuration: Configuration

__all__ = [
    "__version__",
    "AccessKeysApi",
    "AddOnsApi",
    "AgentsApi",
    "AnnotationsApi",
    "ApplicationsApi",
    "AssetsApi",
    "AuditApi",
    "AuthApi",
    "BoardsApi",
    "CacheApi",
    "CalculatedTablesApi",
    "ConditionMonitorsApi",
    "ConditionsApi",
    "ContentApi",
    "ContextApi",
    "CustomAgentsApi",
    "DatafilesApi",
    "DatasourcesApi",
    "DisplayTemplatesApi",
    "DisplaysApi",
    "ExportApi",
    "FoldersApi",
    "FormulasApi",
    "GraphQLApi",
    "HierarchiesApi",
    "ItemsApi",
    "JobsApi",
    "LogsApi",
    "MarkdownItemsApi",
    "MarkdownLinksApi",
    "MaterializedTablesApi",
    "MetricsApi",
    "ModelsApi",
    "MonitorsApi",
    "NetworksApi",
    "NotificationConfigurationsApi",
    "NotifierApi",
    "PluginsApi",
    "ProjectsApi",
    "ReportTemplatesApi",
    "ReportsApi",
    "RequestsApi",
    "SCIMApi",
    "ScalarsApi",
    "SharingApi",
    "SignalMonitorsApi",
    "SignalsApi",
    "StoredTablesApi",
    "SubscriptionsApi",
    "SystemApi",
    "TableDefinitionsApi",
    "TablesApi",
    "TreesApi",
    "UsageApi",
    "UserGroupsApi",
    "UsersApi",
    "WorkbooksApi",
    "AccessKeyInputV1",
    "AccessKeyOutputListV1",
    "AccessKeyOutputV1",
    "AceInputV1",
    "AceOutputV1",
    "AclInputV1",
    "AclOutputV1",
    "ActivityGraphOutputV1",
    "ActivityOutputV1",
    "AddOnInputV1",
    "AddOnOutputListV1",
    "AddOnOutputV1",
    "AddOnPreviewOutputListV1",
    "AddOnPreviewV1",
    "AddOnToolInputV1",
    "AddOnToolOutputV1",
    "AdministratorContactInformationV1",
    "AgentInputV1",
    "AgentKeyOutputV1",
    "AgentOrchestratorOutputV1",
    "AgentOutputV1",
    "AgentStatusOutputV1",
    "AgentStatusV1",
    "AllContextOutputV1",
    "AncestorFilterInputV1",
    "AnnotationImageLinkOutputV1",
    "AnnotationInputV1",
    "AnnotationInterestInputV1",
    "AnnotationInterestOutputV1",
    "AnnotationListOutputV1",
    "AnnotationOutputV1",
    "ApplicationInputV1",
    "ApplicationKeyInputV1",
    "ApplicationOutputV1",
    "ArchiveOutputV1",
    "AssetBatchInputV1",
    "AssetError",
    "AssetGroupAssetInputV1",
    "AssetGroupInputV1",
    "AssetGroupOutputV1",
    "AssetGroupRootInputV1",
    "AssetGroupTreeOutputV1",
    "AssetInputV1",
    "AssetOutputV1",
    "AssetSelectionInputV1",
    "AssetSelectionOutputV1",
    "AssetTreeBatchInputV1",
    "AssetTreeOutputV1",
    "AssetTreeSingleInputV1",
    "AttachmentInputV1",
    "AuditOutputListV1",
    "AuditOutputV1",
    "AuthInputV1",
    "AuthProvidersOutputV1",
    "AuthoritativeRegionOutputV1",
    "BaseManualRunInputV1",
    "BaseOutput",
    "BatchArchiveContextLabelsInputV1",
    "BoardCreateInputV1",
    "BoardFilterCreateInputV1",
    "BoardFilterInputV1",
    "BoardFilterOutputV1",
    "BoardFilterUpdateInputV1",
    "BoardOutputListV1",
    "BoardOutputV1",
    "BoardTileGetInputV1",
    "BoardTimeframeComparisonInputV1",
    "BoardTimeframeComparisonMetricOutputV1",
    "BoardTimeframeComparisonResultOutputV1",
    "BoardTimeframeComparisonTileOutputV1",
    "BoardUpdateInputV1",
    "BooleanConfigFieldV1",
    "CacheBlock",
    "CacheInfoV1",
    "CalculatedItemOutputV1",
    "CalculatedTableColumnDependencyOutputV1",
    "CalculatedTableColumnInputV1",
    "CalculatedTableColumnMetadataOutputV1",
    "CalculatedTableDataQueryInputV1",
    "CalculatedTableInputV1",
    "CalculatedTableListOutputV1",
    "CalculatedTableOutputV1",
    "CapabilityInheritanceOutputV1",
    "CapsuleEventInputV1",
    "CapsuleInputV1",
    "CapsulePropertyInputV1",
    "CapsulePropertyOutputV1",
    "CapsuleV1",
    "CapsulesInputV1",
    "CapsulesOutputV1",
    "CapsulesOverwriteInputV1",
    "CategoryLabelPairInputV1",
    "ChannelOutputV1",
    "ChartDataPointOutputV1",
    "ChartDataResultOutputV1",
    "ColumnDataUpdateInputListV1",
    "ColumnDataUpdateInputV1",
    "ColumnDefinitionBulkEditInputListV1",
    "ColumnDefinitionBulkEditInputV1",
    "ColumnDefinitionInputListV1",
    "ColumnDefinitionInputV1",
    "ColumnDefinitionOrderInputV1",
    "ColumnDefinitionOutputV1",
    "ColumnHeaderOutputV1",
    "ColumnModelInputV1",
    "ColumnModelOutput",
    "ColumnOverrideInputListV1",
    "ColumnOverrideInputV1",
    "ColumnRuleAncestorInputV1",
    "ColumnRuleAssetCreatorInputV1",
    "ColumnRuleConcatInputV1",
    "ColumnRuleConstantInputV1",
    "ColumnRuleContextConditionInputV1",
    "ColumnRuleDatasourceInputV1",
    "ColumnRuleDescendantInputV1",
    "ColumnRuleDescendantSearchInputV1",
    "ColumnRuleEventAssetCreatorInputV1",
    "ColumnRuleEventPropertyInputV1",
    "ColumnRuleFindDescendantInputV1",
    "ColumnRuleFindPropertyInputV1",
    "ColumnRuleFormulaCreatorInputV1",
    "ColumnRuleGetItemPropertyInputV1",
    "ColumnRuleInputV1",
    "ColumnRuleItemSearchInputV1",
    "ColumnRuleItemTypeInputV1",
    "ColumnRuleManagerInputV1",
    "ColumnRuleOutputV1",
    "ColumnRulePathInputV1",
    "ColumnRulePathSearchInputV1",
    "ColumnRulePreserveExistingInputV1",
    "ColumnRuleScalarCreatorInputV1",
    "ColumnRuleSearchAncestorInputV1",
    "ColumnRuleSetItemPropertyInputV1",
    "ColumnRuleTextExtractorInputV1",
    "ColumnRuleTextReplacementInputV1",
    "ColumnRuleTreePathCreatorInputV1",
    "ColumnValuesOutputV1",
    "CommentCategoryInputV1",
    "CommentCategoryOutputListV1",
    "CommentCategoryOutputV1",
    "ComplexObjectConfigFieldV1",
    "CompositeFilter",
    "ConditionBatchInputV1",
    "ConditionInputV1",
    "ConditionMonitorInputV1",
    "ConditionMonitorMetadataOutputListV1",
    "ConditionMonitorMetadataOutputV1",
    "ConditionMonitorNotificationConfigurationInputV1",
    "ConditionMonitorOutputV1",
    "ConditionMonitorWorkbookOutputV1",
    "ConditionOutputV1",
    "ConditionSourceV1",
    "ConditionTableInputV1",
    "ConditionTableStatInputForDirectItemsV1",
    "ConditionTableStatInputForTableV1",
    "ConditionUpdateInputV1",
    "ConfigFieldV1",
    "ConfigurationInputV1",
    "ConfigurationOptionInputV1",
    "ConfigurationOptionOutputSimpleV1",
    "ConfigurationOptionOutputV1",
    "ConfigurationOutputV1",
    "ConfiguredDirectivesOutputV1",
    "ConnectionInputV1",
    "ConnectionOutputV1",
    "ConnectionStatusOutputV1",
    "ConnectionStatusV1",
    "ConnectionsOutputV1",
    "ConnectorInputV1",
    "ConnectorOutputV1",
    "ConnectorsOutputV1",
    "ContentInputV1",
    "ContentOutputV1",
    "ContentWithMetadataListOutputV1",
    "ContentWithMetadataOutputV1",
    "ContextCommentInputV1",
    "ContextCommentListOutputV1",
    "ContextCommentOutputV1",
    "ContextConditionOutputListV1",
    "ContextConditionOutputV1",
    "ContextIdInputV1",
    "ContextItem",
    "ContextLabelInputV1",
    "ContextLabelListOutputV1",
    "ContextLabelOutputV1",
    "ContextLabelWithIdInputV1",
    "ContextNumericInputV1",
    "ContextNumericListOutputV1",
    "ContextNumericOutputV1",
    "ContextOpaqueInputV1",
    "ContextOpaqueListOutputV1",
    "ContextOpaqueOutputV1",
    "ContextPermissionDeniedOutputV1",
    "ContextSourceInputV1",
    "ContextSourceOutputV1",
    "ContextUser",
    "CsvDatafileOutputV1",
    "Cursor",
    "CustomAgentDraftCreateInputV1",
    "CustomAgentDraftInfoOutputV1",
    "CustomAgentDraftOutputV1",
    "CustomAgentDraftUpdateInputV1",
    "CustomAgentInputV1",
    "CustomAgentMetaOutputV1",
    "CustomAgentMetadataUpdateInputV1",
    "CustomAgentOutputV1",
    "CustomAgentProductionInputV1",
    "CustomAgentRevisionOutputV1",
    "CustomAgentSummaryOutputV1",
    "CustomAgentVersionOutputV1",
    "DatafileInputV1",
    "DatafileOutputV1",
    "DatafilesCsvBody",
    "DatasourceAccessStatsV1",
    "DatasourceCacheClearOutputV1",
    "DatasourceCleanUpInputV1",
    "DatasourceCleanUpOutputV1",
    "DatasourceInputV1",
    "DatasourceOutputListV1",
    "DatasourceOutputV1",
    "DatasourcePairOutputV1",
    "DatasourcePairsOutputV1",
    "DatasourcePreviewV1",
    "DatasourceStatisticsV1",
    "DatasourceStatusOutputV1",
    "DatasourceStatusV1",
    "DatasourceSummaryStatusOutputV1",
    "DatasourcesStatusOutputV1",
    "DateRangeInputV1",
    "DateRangeOutputV1",
    "DebugCacheBlockOutputV1",
    "DeleteColumnErrorOutputV1",
    "DeleteResultOutputV1",
    "DeleteRowsInputV1",
    "DeleteRowsOutputV1",
    "DerivedFeatureV1",
    "DetailedMeterOutputV1",
    "DetailedTimerOutputV1",
    "DirectItemIdsSourceV1",
    "DirectiveInputV1",
    "DisplayInputV1",
    "DisplayOutputListV1",
    "DisplayOutputV1",
    "DisplayTemplateInputV1",
    "DisplayTemplateOutputListV1",
    "DisplayTemplateOutputV1",
    "DocumentBackupOutputV1",
    "DoubleConfigFieldV1",
    "DurationConfigFieldV1",
    "EmailNotificationRecipientOutputV1",
    "EmailerConfigurationOutputV1",
    "EnumConfigFieldV1",
    "ExportItemV1",
    "ExportItemsOutputV1",
    "ExportItemsV1",
    "ExportPreviewListV1",
    "ExportPreviewV1",
    "FeatureArgumentOutputV1",
    "FeatureOutputV1",
    "FeatureRuleV1",
    "FeatureValueOutputV1",
    "Filter",
    "FixedListFilterInputV1",
    "FixedListSearchV1",
    "FoldedStackNodeV1",
    "FolderInputV1",
    "FolderNavigationOutputV1",
    "FolderOutputV1",
    "FolderSearchResultsV1",
    "FormulaCompileInputV1",
    "FormulaCompileOutputV1",
    "FormulaCompilerErrorOutputV1",
    "FormulaDependencyInputV1",
    "FormulaDocExampleInputV1",
    "FormulaDocExampleListInputV1",
    "FormulaDocInputV1",
    "FormulaDocKeywordListInputV1",
    "FormulaDocOutputV1",
    "FormulaDocSummariesOutputV1",
    "FormulaDocSummaryOutputV1",
    "FormulaErrorOutputV1",
    "FormulaExampleOutputV1",
    "FormulaGenericOutputV1",
    "FormulaItemInputV1",
    "FormulaItemOutputV1",
    "FormulaLogEntry",
    "FormulaLogEntryDetails",
    "FormulaLogV1",
    "FormulaPackageImportInputV1",
    "FormulaPackageImportOutputV1",
    "FormulaPackageInputV1",
    "FormulaPackageOutputV1",
    "FormulaParameterInputV1",
    "FormulaParameterOutputV1",
    "FormulaRunInputV1",
    "FormulaRunOutputV1",
    "FormulaToken",
    "FormulaUpdateInputV1",
    "FormulaUpgradeChangeV1",
    "FormulaUpgradeOutputV1",
    "FunctionInputV1",
    "FunctionParameterOutputV1",
    "FunctionVariantOutputV1",
    "GaugeDatumV1",
    "GenerateChartDataInputV1",
    "GenericEventInputV1",
    "GenericTableOutputV1",
    "GetAddOnToolsOutputV1",
    "GetAllContextInputV1",
    "GetApplicationsOutputV1",
    "GetChannelsOutputV1",
    "GetConditionMonitorItemsOutputV1",
    "GetContentItemsOutputV1",
    "GetContextConditionInputV1",
    "GetContextInputV1",
    "GetDateRangesOutputV1",
    "GetJobsOutputV1",
    "GetMetricsOutputV1",
    "GetOrganizationsOutputV1",
    "GetProjectsOutputV1",
    "GetRequestOutputV1",
    "GetRequestsOutputV1",
    "GetSampleOutputV1",
    "GetSamplesOutputV1",
    "GetSignalMonitorItemsOutputV1",
    "GetSignalsOutputV1",
    "GraphQLInputV1",
    "GraphQLOutputV1",
    "GroupBy",
    "GroupValueColumn",
    "HierarchyInputV1",
    "HierarchyNodeOutputListV1",
    "HierarchyNodeOutputV1",
    "HierarchyNodeWithPathOutputV1",
    "HierarchyOutputListV1",
    "HierarchyOutputV1",
    "HierarchySearchOutputV1",
    "HierarchySearchV1",
    "HierarchyValidationOutputV1",
    "IdImagesBody",
    "IdentityMappingListV1",
    "IdentityMappingV1",
    "IdentityPreviewListV1",
    "IdentityPreviewV1",
    "ImportTableCSVOutputV1",
    "IndexingParametersInputV1",
    "InputFeatureV1",
    "InstallerOutputV1",
    "InstanceOutputMappingV1",
    "InstanceOutputPaginatedListV1",
    "InstanceOutputV1",
    "InstanceRetiredOutputV1",
    "IntervalV1",
    "InvalidSwapOutV1",
    "IssueSummaryOutputV1",
    "ItemBatchOutputV1",
    "ItemDependencyOutputV1",
    "ItemEventInputV1",
    "ItemFinderInputV1",
    "ItemFinderOutputListV1",
    "ItemFinderOutputV1",
    "ItemFinderSearchesInputV1",
    "ItemFinderSearchesOutputV1",
    "ItemIdListInputV1",
    "ItemMetadata",
    "ItemOutputV1",
    "ItemParameterOfOutputV1",
    "ItemPreviewListV1",
    "ItemPreviewV1",
    "ItemPreviewWithAssetsV1",
    "ItemSearchInputV1",
    "ItemSearchPreviewListV1",
    "ItemSearchPreviewPaginatedListV1",
    "ItemSearchPreviewV1",
    "ItemSwapResultOutputV1",
    "ItemUpdateOutputV1",
    "ItemUserAttributesInputV1",
    "ItemUserAttributesOutputV1",
    "ItemWithSwapPairsV1",
    "JiraAttachment",
    "JobAcceptedOutputV1",
    "JobOutputV1",
    "JoinInputV1",
    "JsonBackupOutputV1",
    "KpiDataOutputV1",
    "LabelCategoryInputV1",
    "LabelCategoryOutputListV1",
    "LabelCategoryOutputV1",
    "LabelHierarchyInputV1",
    "LabelHierarchyOutputListV1",
    "LabelHierarchyOutputV1",
    "LabelInputV1",
    "LabelOutputListV1",
    "LabelOutputV1",
    "LastRunStateOutputV1",
    "LicenseImporterOutputV1",
    "LicenseStatusOutputV1",
    "LicensedFeatureStatusOutputV1",
    "ListConfigFieldV1",
    "LockErrorOutputV1",
    "LockErrorPathOutputV1",
    "LockErrorsOutputV1",
    "LockItemOutputV1",
    "LockedItemListOutputV1",
    "LogMessage",
    "LogMessageInputV1",
    "LogMessageOutputV1",
    "LongConfigFieldV1",
    "ManualRunInputV1",
    "MapMarkerRehydrationInstructionsInputV1",
    "MapMarkerRehydrationInstructionsOutputV1",
    "MarkdownItemInputV1",
    "MarkdownItemListV1",
    "MarkdownItemOutputV1",
    "MarkdownLinkUploadOutputV1",
    "MarkdownLinksBody",
    "MaterializedTableHeaderV1",
    "MaterializedTableSourceV1",
    "MaterializedTableV1",
    "MediaType",
    "MentionInputV1",
    "MeterDatumV1",
    "MigrateEditorInputV1",
    "ModelApplicationErrorOutputV1",
    "ModelApplicationMappingV1",
    "ModelBooleanConstantRuleV1",
    "ModelDerivedColumnNamesInputV1",
    "ModelDraftCreateInputV1",
    "ModelDuplicateInputV1",
    "ModelFormulaCreatorRuleV1",
    "ModelFromIdsInputV1",
    "ModelInitialApplicationInputV1",
    "ModelInputV1",
    "ModelOutputListV1",
    "ModelOutputV1",
    "ModelPublishInputV1",
    "ModelReapplicationInputV1",
    "ModelRuleInputV1ListString",
    "ModelRuleInputV1Object",
    "ModelRuleInputV1String",
    "ModelRuleInputV1UUID",
    "ModelScalarCreatorRuleV1",
    "ModelTableApplicationOutputV1",
    "ModelTableApplicationsOutputListV1",
    "ModelTableApplicationsOutputV1",
    "ModelVersionListOutputV1",
    "ModelVersionOutputV1",
    "MonitorDefinitionOutputV1",
    "MonitorDefinitionsOutputV1",
    "MonitorInputV1",
    "MonitorOutputV1",
    "MonitorValues",
    "MonitoredConditionOutputListV1",
    "MonitoredConditionOutputV1",
    "MonitoredSignalLastRunStateOutputV1",
    "MonitoredSignalOutputListV1",
    "MonitoredSignalOutputV1",
    "MonitorsOutputV1",
    "NodePathInputV1",
    "NotifiableReportOutputListV1",
    "NotifiableReportOutputV1",
    "NotificationConfigurationOutputV1",
    "NumericDescriptionInputV1",
    "NumericDescriptionOutputListV1",
    "NumericDescriptionOutputV1",
    "OptionalReportInputV1",
    "OrderByInputV1",
    "OrganizationInputV1",
    "OrganizationOutputV1",
    "ParameterDocOutputV1",
    "PasswordResetInput",
    "PermissionsV1",
    "PluginOutputListV1",
    "PluginOutputV1",
    "PluginsBody",
    "PreCachedConditionCapsulePropertyInfoV1",
    "PreProvisionInputV1",
    "PreProvisionOutputV1",
    "PrecachedItemOutputV1",
    "PrecachedItemsOutputV1",
    "PriorityV1",
    "ProgressInformationOutputV1",
    "ProjectInputV1",
    "ProjectOutputV1",
    "PropertiesForItemUUIDColumn",
    "PropertiesForItemUUIDColumnInputV1",
    "PropertyFilterInputV1",
    "PropertyHrefOutputV1",
    "PropertyInputV1",
    "PropertyOutputV1",
    "PropertySearchV1",
    "ProvisionInputV1",
    "PublishEventsInputV1",
    "PublishEventsOutputV1",
    "PutAssetInputV1",
    "PutScalarInputV1",
    "PutScalarsInputV1",
    "PutSignalsInputV1",
    "PutUserGroupsInputV1",
    "RadialGaugeRehydrationInstructionsInputV1",
    "RadialGaugeRehydrationInstructionsOutputV1",
    "RadialRehydrationInstructionsInputV1",
    "RadialRehydrationInstructionsOutputV1",
    "RecomputeTableInputV1",
    "RecomputeTableOutputV1",
    "ReferencedInputItemV1",
    "ReferencedItemsOutputV1",
    "ReferencedOutputItemV1",
    "ReferencedTableDefinitionIdsOutputV1",
    "RegexConfigFieldV1",
    "RegressionOutputV1",
    "RehydrationInstructionsInputV1",
    "RehydrationInstructionsOutputV1",
    "RehydrationSeriesLookupInputV1",
    "RehydrationSeriesLookupOutputV1",
    "ReleaseNotesOutputV1",
    "RemoteAgentDirectivesOutputV1",
    "RemoteAgentStatusInputV1",
    "RemoteAgentStatusOutputV1",
    "ReportInputItemV1",
    "ReportInputV1",
    "ReportNotificationConfigurationInputV1",
    "ReportTemplateInputV1",
    "ReportTemplateOutputV1",
    "RequestOutputV1",
    "RequestPasswordResetInput",
    "RowEventInputV1",
    "RowId",
    "RowIdInputListV1",
    "RowIdInputV1",
    "RowRulesResultV1",
    "RulesResultMessageV1",
    "RulesResultV1",
    "RunConditionMonitorJobInputV1",
    "SampleInputV1",
    "SampleOutputV1",
    "SamplesInputV1",
    "SamplesOutputV1",
    "SamplesOverwriteInputV1",
    "ScalarEvaluateOutputV1",
    "ScalarInputV1",
    "ScalarPropertyV1",
    "ScalarValueOutputV1",
    "ScaleAcrossTreeOutputV1",
    "ScalingTableUUIDColumnSearchV1",
    "SchedulableAdminListOutputV1",
    "SchedulableAdminOutputV1",
    "SchedulableSummaryDayOutputV1",
    "SchedulableSummaryWeekOutputV1",
    "SchedulableWorkbookOutputV1",
    "ScheduleInputV1",
    "ScheduleOutputV1",
    "ScheduledNotebookInputV1",
    "ScheduledNotebookListOutputV1",
    "ScheduledNotebookOutputV1",
    "ScheduledNotebookResultInputV1",
    "ScimTokenInputV1",
    "ScimTokenOutputV1",
    "ScreenshotOutputV1",
    "SecretConfigFieldV1",
    "SecretStatus",
    "SeeAlsoDocOutputV1",
    "SendEmailAttachmentV1",
    "SendEmailContactV1",
    "SendEmailInputV1",
    "SentEmailAttachmentOutputV1",
    "SentEmailOutputV1",
    "SentEmailsListOutputV1",
    "ServerBuildInfoOutputV1",
    "ServerLoadOutputV1",
    "ServerSpecOutputV1",
    "ServerStatusOutputV1",
    "SetTrustInputV1",
    "SharedColumnsOutputV1",
    "SharedItemInformation",
    "SignalInputV1",
    "SignalMonitorInputV1",
    "SignalMonitorMetadataOutputListV1",
    "SignalMonitorMetadataOutputV1",
    "SignalMonitorOutputV1",
    "SignalMonitorWorkbookOutputV1",
    "SignalOutputV1",
    "SignalWithIdInputV1",
    "SimpleFilter",
    "Sort",
    "StatusMessage",
    "StatusMessageBase",
    "StoreSecretInputV1",
    "StoredTableCSVInputV1",
    "StoredTableColumnInputV1",
    "StoredTableColumnOutputV1",
    "StoredTableDeleteRowsInputV1",
    "StoredTableOutputV1",
    "StoredTableSearchFailureOutputListV1",
    "StoredTableSearchFailureOutputV1",
    "StoredTableSearchV1",
    "StoredtablesCsvBody",
    "StringConfigFieldV1",
    "SubscriptionInputV1",
    "SubscriptionOutputV1",
    "SubscriptionUpdateInputV1",
    "SupportRequestInputV1",
    "SupportRequestOutputV1",
    "SupportedUnitsOutputV1",
    "SuppressConditionInputV1",
    "SuppressedConditionInputV1",
    "SuppressedConditionOutputV1",
    "SwapAcrossAssetsSearchV1",
    "SwapInputV1",
    "SwapOptionListV1",
    "SwapOptionV1",
    "SwapOutputV1",
    "SyncProgress",
    "SyncProgressOutputV1",
    "SystemLicenseBody",
    "TableApplicationRetiredOutputV1",
    "TableColumnOutputV1",
    "TableComputeOutputV1",
    "TableDataQueryInputV1",
    "TableDefinitionCSVInputV1",
    "TableDefinitionCSVPublishRowsInputV1",
    "TableDefinitionCSVPublishRowsOutputV1",
    "TableDefinitionCSVUpdateInputV1",
    "TableDefinitionInputV1",
    "TableDefinitionMetadataOutputV1",
    "TableDefinitionOutputListV1",
    "TableDefinitionOutputV1",
    "TableDefinitionPreviewInputV1",
    "TableDefinitionPreviewOutputV1",
    "TableDefinitionUpdateInputV1",
    "TableFormula",
    "TableJoinInput",
    "TableModelApplicationInputV1",
    "TablePropertyFilterInputV1",
    "TablePropertyInputV1",
    "TableResultOutputV1",
    "TabledefinitionsCsvBody",
    "ThresholdMetricInputV1",
    "ThresholdMetricOutputV1",
    "ThresholdOutputV1",
    "TileCreateInputV1",
    "TileLayoutOutputV1",
    "TileOutputV1",
    "TileUpdateInputV1",
    "TimeInterval",
    "TimerDatumV1",
    "TopicSandboxInputV1",
    "TreeItemOutputV1",
    "TreemapItemOutputV1",
    "TreemapOutputV1",
    "UnitsOfMeasureBatchInputV1",
    "UnitsOfMeasureItemV1",
    "UnitsOfMeasureOutputV1",
    "UnsubscribeOutputV1",
    "UpdatedRowsOutputV1",
    "UsageOutputListV1",
    "UsageOutputV1",
    "UsageTypesV1",
    "UserGroupInputV1",
    "UserGroupOutputV1",
    "UserGroupWithIdInputV1",
    "UserInputV1",
    "UserOutputListV1",
    "UserOutputV1",
    "UserPasswordInputV1",
    "ValidateCronListInputV1",
    "ValidateCronListOutputV1",
    "ValidateCronOutputV1",
    "Value",
    "ValueFilter",
    "VersionHistoryOutputListV1",
    "VersionHistoryOutputV1",
    "VersionInputV1",
    "VersionOutputV1",
    "VersionSourceItemOutputV1",
    "VersionSourceOutputV1",
    "ViewColumnFilterInputV1",
    "ViewColumnFilterOutputV1",
    "ViewColumnInputV1",
    "ViewColumnOutputV1",
    "VirtualColumns",
    "WorkbenchItemOutputListV1",
    "WorkbenchSearchResultPreviewV1",
    "WorkbookInputV1",
    "WorkbookOutputListV1",
    "WorkbookOutputV1",
    "WorkbookOwnerOutputV1",
    "WorksheetInputV1",
    "WorksheetOutputListV1",
    "WorksheetOutputV1",
    "WorkstepChronologyEntryV1",
    "WorkstepChronologyOutputV1",
    "WorkstepInputV1",
    "WorkstepOutputV1",
    "ApiClient",
    "Configuration",
    "configuration",
]



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ConditionMonitorsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_condition_monitor(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_condition_monitor_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_condition_monitor(
        self,
        **kwargs: Any,
    ) -> ConditionMonitorOutputV1: ...

    def create_condition_monitor_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_condition_monitor(
        self,
        **kwargs: Any,
    ) -> ConditionMonitorOutputV1: ...

    def get_condition_monitor_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_condition_monitor_metadata_list(
        self,
        **kwargs: Any,
    ) -> ConditionMonitorMetadataOutputListV1: ...

    def get_condition_monitor_metadata_list_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_condition_monitor_suppressions(
        self,
        **kwargs: Any,
    ) -> List[SuppressedConditionOutputV1]: ...

    def get_condition_monitor_suppressions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_condition_monitors(
        self,
        **kwargs: Any,
    ) -> GetConditionMonitorItemsOutputV1: ...

    def get_condition_monitors_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_monitored_conditions(
        self,
        **kwargs: Any,
    ) -> MonitoredConditionOutputListV1: ...

    def get_monitored_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def run_condition_monitor_job(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def run_condition_monitor_job_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def suppress_conditions(
        self,
        **kwargs: Any,
    ) -> None: ...

    def suppress_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def unsuppress_conditions(
        self,
        **kwargs: Any,
    ) -> None: ...

    def unsuppress_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_condition_monitor(
        self,
        **kwargs: Any,
    ) -> ConditionMonitorOutputV1: ...

    def update_condition_monitor_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardTimeframeComparisonMetricOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _baseline_value: Optional[float]
    _column: str
    _current_value: Optional[float]
    _delta: Optional[float]
    _metric: str
    _percent_change: Optional[float]


    def __init__(
        self,
        baseline_value: Optional[float] = None,
        column: Optional[str] = None,
        current_value: Optional[float] = None,
        delta: Optional[float] = None,
        metric: Optional[str] = None,
        percent_change: Optional[float] = None,
    ) -> None: ...

    @property
    def baseline_value(self) -> Optional[float]: ...

    @baseline_value.setter
    def baseline_value(self, baseline_value: Optional[float]) -> None: ...

    @property
    def column(self) -> str: ...

    @column.setter
    def column(self, column: str) -> None: ...

    @property
    def current_value(self) -> Optional[float]: ...

    @current_value.setter
    def current_value(self, current_value: Optional[float]) -> None: ...

    @property
    def delta(self) -> Optional[float]: ...

    @delta.setter
    def delta(self, delta: Optional[float]) -> None: ...

    @property
    def metric(self) -> str: ...

    @metric.setter
    def metric(self, metric: str) -> None: ...

    @property
    def percent_change(self) -> Optional[float]: ...

    @percent_change.setter
    def percent_change(self, percent_change: Optional[float]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class InstanceOutputMappingV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'boolean_output': 'bool',
        'feature_id': 'str',
        'is_archived': 'bool',
        'output_id': 'str',
        'output_id_inactive': 'bool'
    }

    attribute_map = {
        'boolean_output': 'booleanOutput',
        'feature_id': 'featureId',
        'is_archived': 'isArchived',
        'output_id': 'outputId',
        'output_id_inactive': 'outputIdInactive'
    }

    def __init__(self, boolean_output=None, feature_id=None, is_archived=None, output_id=None, output_id_inactive=None):
        """
        InstanceOutputMappingV1 - a model defined in Swagger
        """

        self._boolean_output = None
        self._feature_id = None
        self._is_archived = None
        self._output_id = None
        self._output_id_inactive = None

        if boolean_output is not None:
          self.boolean_output = boolean_output
        if feature_id is not None:
          self.feature_id = feature_id
        if is_archived is not None:
          self.is_archived = is_archived
        if output_id is not None:
          self.output_id = output_id
        if output_id_inactive is not None:
          self.output_id_inactive = output_id_inactive

    @property
    def boolean_output(self):
        """
        Gets the boolean_output of this InstanceOutputMappingV1.
        Boolean literal output, if applicable

        :return: The boolean_output of this InstanceOutputMappingV1.
        :rtype: bool
        """
        return self._boolean_output

    @boolean_output.setter
    def boolean_output(self, boolean_output):
        """
        Sets the boolean_output of this InstanceOutputMappingV1.
        Boolean literal output, if applicable

        :param boolean_output: The boolean_output of this InstanceOutputMappingV1.
        :type: bool
        """

        self._boolean_output = boolean_output

    @property
    def feature_id(self):
        """
        Gets the feature_id of this InstanceOutputMappingV1.
        Feature ID

        :return: The feature_id of this InstanceOutputMappingV1.
        :rtype: str
        """
        return self._feature_id

    @feature_id.setter
    def feature_id(self, feature_id):
        """
        Sets the feature_id of this InstanceOutputMappingV1.
        Feature ID

        :param feature_id: The feature_id of this InstanceOutputMappingV1.
        :type: str
        """

        self._feature_id = feature_id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this InstanceOutputMappingV1.

        :return: The is_archived of this InstanceOutputMappingV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this InstanceOutputMappingV1.

        :param is_archived: The is_archived of this InstanceOutputMappingV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def output_id(self):
        """
        Gets the output_id of this InstanceOutputMappingV1.
        ID of the Item created by the associated Feature, if applicable

        :return: The output_id of this InstanceOutputMappingV1.
        :rtype: str
        """
        return self._output_id

    @output_id.setter
    def output_id(self, output_id):
        """
        Sets the output_id of this InstanceOutputMappingV1.
        ID of the Item created by the associated Feature, if applicable

        :param output_id: The output_id of this InstanceOutputMappingV1.
        :type: str
        """

        self._output_id = output_id

    @property
    def output_id_inactive(self):
        """
        Gets the output_id_inactive of this InstanceOutputMappingV1.
        Whether the outputId has been overwritten by a null value. If true, the outputId is for information purposes only, and the current value is null.

        :return: The output_id_inactive of this InstanceOutputMappingV1.
        :rtype: bool
        """
        return self._output_id_inactive

    @output_id_inactive.setter
    def output_id_inactive(self, output_id_inactive):
        """
        Sets the output_id_inactive of this InstanceOutputMappingV1.
        Whether the outputId has been overwritten by a null value. If true, the outputId is for information purposes only, and the current value is null.

        :param output_id_inactive: The output_id_inactive of this InstanceOutputMappingV1.
        :type: bool
        """

        self._output_id_inactive = output_id_inactive

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, InstanceOutputMappingV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardFilterCreateInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'board_id': 'str',
        'config': 'str',
        'display_type': 'str'
    }

    attribute_map = {
        'board_id': 'boardId',
        'config': 'config',
        'display_type': 'displayType'
    }

    def __init__(self, board_id=None, config=None, display_type=None):
        """
        BoardFilterCreateInputV1 - a model defined in Swagger
        """

        self._board_id = None
        self._config = None
        self._display_type = None

        if board_id is not None:
          self.board_id = board_id
        if config is not None:
          self.config = config
        if display_type is not None:
          self.display_type = display_type

    @property
    def board_id(self):
        """
        Gets the board_id of this BoardFilterCreateInputV1.
        Identifier of the board this filter belongs to

        :return: The board_id of this BoardFilterCreateInputV1.
        :rtype: str
        """
        return self._board_id

    @board_id.setter
    def board_id(self, board_id):
        """
        Sets the board_id of this BoardFilterCreateInputV1.
        Identifier of the board this filter belongs to

        :param board_id: The board_id of this BoardFilterCreateInputV1.
        :type: str
        """
        if board_id is None:
            raise ValueError("Invalid value for `board_id`, must not be `None`")

        self._board_id = board_id

    @property
    def config(self):
        """
        Gets the config of this BoardFilterCreateInputV1.
        Configuration JSON for the filter

        :return: The config of this BoardFilterCreateInputV1.
        :rtype: str
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this BoardFilterCreateInputV1.
        Configuration JSON for the filter

        :param config: The config of this BoardFilterCreateInputV1.
        :type: str
        """

        self._config = config

    @property
    def display_type(self):
        """
        Gets the display_type of this BoardFilterCreateInputV1.
        The display type for the filter (e.g., select)

        :return: The display_type of this BoardFilterCreateInputV1.
        :rtype: str
        """
        return self._display_type

    @display_type.setter
    def display_type(self, display_type):
        """
        Sets the display_type of this BoardFilterCreateInputV1.
        The display type for the filter (e.g., select)

        :param display_type: The display_type of this BoardFilterCreateInputV1.
        :type: str
        """

        self._display_type = display_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardFilterCreateInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class WorksheetInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _branch_from: Optional[str]
    _clone_name_prefix: Optional[str]
    _clone_name_suffix: Optional[str]
    _item_ids_to_clone: Optional[List[str]]
    _name: str


    def __init__(
        self,
        branch_from: Optional[str] = None,
        clone_name_prefix: Optional[str] = None,
        clone_name_suffix: Optional[str] = None,
        item_ids_to_clone: Optional[List[str]] = None,
        name: Optional[str] = None,
    ) -> None: ...

    @property
    def branch_from(self) -> Optional[str]: ...

    @branch_from.setter
    def branch_from(self, branch_from: Optional[str]) -> None: ...

    @property
    def clone_name_prefix(self) -> Optional[str]: ...

    @clone_name_prefix.setter
    def clone_name_prefix(self, clone_name_prefix: Optional[str]) -> None: ...

    @property
    def clone_name_suffix(self) -> Optional[str]: ...

    @clone_name_suffix.setter
    def clone_name_suffix(self, clone_name_suffix: Optional[str]) -> None: ...

    @property
    def item_ids_to_clone(self) -> Optional[List[str]]: ...

    @item_ids_to_clone.setter
    def item_ids_to_clone(self, item_ids_to_clone: Optional[List[str]]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ModelApplicationErrorOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _feature_id: Optional[str]
    _message: Optional[str]
    _message_arguments: Optional[Dict[str, str]]
    _message_number: Optional[int]
    _model_id: Optional[str]
    _rule_id: Optional[str]


    def __init__(
        self,
        feature_id: Optional[str] = None,
        message: Optional[str] = None,
        message_arguments: Optional[Dict[str, str]] = None,
        message_number: Optional[int] = None,
        model_id: Optional[str] = None,
        rule_id: Optional[str] = None,
    ) -> None: ...

    @property
    def feature_id(self) -> Optional[str]: ...

    @feature_id.setter
    def feature_id(self, feature_id: Optional[str]) -> None: ...

    @property
    def message(self) -> Optional[str]: ...

    @message.setter
    def message(self, message: Optional[str]) -> None: ...

    @property
    def message_arguments(self) -> Optional[Dict[str, str]]: ...

    @message_arguments.setter
    def message_arguments(self, message_arguments: Optional[Dict[str, str]]) -> None: ...

    @property
    def message_number(self) -> Optional[int]: ...

    @message_number.setter
    def message_number(self, message_number: Optional[int]) -> None: ...

    @property
    def model_id(self) -> Optional[str]: ...

    @model_id.setter
    def model_id(self, model_id: Optional[str]) -> None: ...

    @property
    def rule_id(self) -> Optional[str]: ...

    @rule_id.setter
    def rule_id(self, rule_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class JobsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def create_content_job(
        self,
        **kwargs: Any,
    ) -> JobOutputV1: ...

    def create_content_job_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_date_range_job(
        self,
        **kwargs: Any,
    ) -> JobOutputV1: ...

    def create_date_range_job_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_job(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_job_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_job(
        self,
        **kwargs: Any,
    ) -> JobOutputV1: ...

    def get_job_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_jobs(
        self,
        **kwargs: Any,
    ) -> GetJobsOutputV1: ...

    def get_jobs_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_screenshot_from_content(
        self,
        **kwargs: Any,
    ) -> ScreenshotOutputV1: ...

    def get_screenshot_from_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def validate_cron(
        self,
        **kwargs: Any,
    ) -> ValidateCronListOutputV1: ...

    def validate_cron_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class LogMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'exception': 'str',
        'failure_reasons': 'list[str]',
        'formatted_level': 'str',
        'level': 'str',
        'logger_name': 'str',
        'message': 'str',
        'source': 'str',
        'time': 'str',
        'valid': 'bool'
    }

    attribute_map = {
        'exception': 'exception',
        'failure_reasons': 'failureReasons',
        'formatted_level': 'formattedLevel',
        'level': 'level',
        'logger_name': 'loggerName',
        'message': 'message',
        'source': 'source',
        'time': 'time',
        'valid': 'valid'
    }

    def __init__(self, exception=None, failure_reasons=None, formatted_level=None, level=None, logger_name=None, message=None, source=None, time=None, valid=None):
        """
        LogMessage - a model defined in Swagger
        """

        self._exception = None
        self._failure_reasons = None
        self._formatted_level = None
        self._level = None
        self._logger_name = None
        self._message = None
        self._source = None
        self._time = None
        self._valid = None

        if exception is not None:
          self.exception = exception
        if failure_reasons is not None:
          self.failure_reasons = failure_reasons
        if formatted_level is not None:
          self.formatted_level = formatted_level
        if level is not None:
          self.level = level
        if logger_name is not None:
          self.logger_name = logger_name
        if message is not None:
          self.message = message
        if source is not None:
          self.source = source
        if time is not None:
          self.time = time
        if valid is not None:
          self.valid = valid

    @property
    def exception(self):
        """
        Gets the exception of this LogMessage.
        Exception message if any

        :return: The exception of this LogMessage.
        :rtype: str
        """
        return self._exception

    @exception.setter
    def exception(self, exception):
        """
        Sets the exception of this LogMessage.
        Exception message if any

        :param exception: The exception of this LogMessage.
        :type: str
        """

        self._exception = exception

    @property
    def failure_reasons(self):
        """
        Gets the failure_reasons of this LogMessage.

        :return: The failure_reasons of this LogMessage.
        :rtype: list[str]
        """
        return self._failure_reasons

    @failure_reasons.setter
    def failure_reasons(self, failure_reasons):
        """
        Sets the failure_reasons of this LogMessage.

        :param failure_reasons: The failure_reasons of this LogMessage.
        :type: list[str]
        """

        self._failure_reasons = failure_reasons

    @property
    def formatted_level(self):
        """
        Gets the formatted_level of this LogMessage.

        :return: The formatted_level of this LogMessage.
        :rtype: str
        """
        return self._formatted_level

    @formatted_level.setter
    def formatted_level(self, formatted_level):
        """
        Sets the formatted_level of this LogMessage.

        :param formatted_level: The formatted_level of this LogMessage.
        :type: str
        """

        self._formatted_level = formatted_level

    @property
    def level(self):
        """
        Gets the level of this LogMessage.
        Log level: TRACE, DEBUG, INFO, WARN, ERROR

        :return: The level of this LogMessage.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this LogMessage.
        Log level: TRACE, DEBUG, INFO, WARN, ERROR

        :param level: The level of this LogMessage.
        :type: str
        """
        if level is None:
            raise ValueError("Invalid value for `level`, must not be `None`")

        self._level = level

    @property
    def logger_name(self):
        """
        Gets the logger_name of this LogMessage.
        Logger name

        :return: The logger_name of this LogMessage.
        :rtype: str
        """
        return self._logger_name

    @logger_name.setter
    def logger_name(self, logger_name):
        """
        Sets the logger_name of this LogMessage.
        Logger name

        :param logger_name: The logger_name of this LogMessage.
        :type: str
        """

        self._logger_name = logger_name

    @property
    def message(self):
        """
        Gets the message of this LogMessage.
        Log message

        :return: The message of this LogMessage.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this LogMessage.
        Log message

        :param message: The message of this LogMessage.
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")

        self._message = message

    @property
    def source(self):
        """
        Gets the source of this LogMessage.
        Thread name

        :return: The source of this LogMessage.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this LogMessage.
        Thread name

        :param source: The source of this LogMessage.
        :type: str
        """
        if source is None:
            raise ValueError("Invalid value for `source`, must not be `None`")

        self._source = source

    @property
    def time(self):
        """
        Gets the time of this LogMessage.
        Timestamp for the log message in ISO-8601 format

        :return: The time of this LogMessage.
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """
        Sets the time of this LogMessage.
        Timestamp for the log message in ISO-8601 format

        :param time: The time of this LogMessage.
        :type: str
        """
        if time is None:
            raise ValueError("Invalid value for `time`, must not be `None`")

        self._time = time

    @property
    def valid(self):
        """
        Gets the valid of this LogMessage.

        :return: The valid of this LogMessage.
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """
        Sets the valid of this LogMessage.

        :param valid: The valid of this LogMessage.
        :type: bool
        """

        self._valid = valid

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LogMessage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleEventAssetCreatorInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'identity_id': 'str',
        'permission_string': 'str',
        'property_name': 'str'
    }

    attribute_map = {
        'description': 'description',
        'identity_id': 'identityId',
        'permission_string': 'permissionString',
        'property_name': 'propertyName'
    }

    def __init__(self, description=None, identity_id=None, permission_string=None, property_name=None):
        """
        ColumnRuleEventAssetCreatorInputV1 - a model defined in Swagger
        """

        self._description = None
        self._identity_id = None
        self._permission_string = None
        self._property_name = None

        if description is not None:
          self.description = description
        if identity_id is not None:
          self.identity_id = identity_id
        if permission_string is not None:
          self.permission_string = permission_string
        if property_name is not None:
          self.property_name = property_name

    @property
    def description(self):
        """
        Gets the description of this ColumnRuleEventAssetCreatorInputV1.
        Clarifying information or other plain language description for assets created by this rule. An input of just whitespace is equivalent to a null input.

        :return: The description of this ColumnRuleEventAssetCreatorInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ColumnRuleEventAssetCreatorInputV1.
        Clarifying information or other plain language description for assets created by this rule. An input of just whitespace is equivalent to a null input.

        :param description: The description of this ColumnRuleEventAssetCreatorInputV1.
        :type: str
        """

        self._description = description

    @property
    def identity_id(self):
        """
        Gets the identity_id of this ColumnRuleEventAssetCreatorInputV1.
        The ID of the identity for which permissions will be set on items created by this rule. A null value means that the items created by this rule will have the same permissions as its associated datasource. Must be set along with permissionString.

        :return: The identity_id of this ColumnRuleEventAssetCreatorInputV1.
        :rtype: str
        """
        return self._identity_id

    @identity_id.setter
    def identity_id(self, identity_id):
        """
        Sets the identity_id of this ColumnRuleEventAssetCreatorInputV1.
        The ID of the identity for which permissions will be set on items created by this rule. A null value means that the items created by this rule will have the same permissions as its associated datasource. Must be set along with permissionString.

        :param identity_id: The identity_id of this ColumnRuleEventAssetCreatorInputV1.
        :type: str
        """

        self._identity_id = identity_id

    @property
    def permission_string(self):
        """
        Gets the permission_string of this ColumnRuleEventAssetCreatorInputV1.
        The permissions for the identity included for items created by this rule. Must be in a valid string form with each permission separated by a comma, for example 'r,w,m'. Acceptable permissions are: 'r' - read, 'w' - write, 'm' - manage.Must be set along with identityId.

        :return: The permission_string of this ColumnRuleEventAssetCreatorInputV1.
        :rtype: str
        """
        return self._permission_string

    @permission_string.setter
    def permission_string(self, permission_string):
        """
        Sets the permission_string of this ColumnRuleEventAssetCreatorInputV1.
        The permissions for the identity included for items created by this rule. Must be in a valid string form with each permission separated by a comma, for example 'r,w,m'. Acceptable permissions are: 'r' - read, 'w' - write, 'm' - manage.Must be set along with identityId.

        :param permission_string: The permission_string of this ColumnRuleEventAssetCreatorInputV1.
        :type: str
        """

        self._permission_string = permission_string

    @property
    def property_name(self):
        """
        Gets the property_name of this ColumnRuleEventAssetCreatorInputV1.
        The property to choose from an event to select a Hierarchy Node. The property name can include dot notation to specify ancestor or child items. Supported: children[<child name>] for children, parent[<level>] or ancestor[<level] for an ancestor at a specific level, or parent[<level>].children[<child name>] or ancestor[<level>].children[<child name>] for a child of an ancestor at a specific level.

        :return: The property_name of this ColumnRuleEventAssetCreatorInputV1.
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """
        Sets the property_name of this ColumnRuleEventAssetCreatorInputV1.
        The property to choose from an event to select a Hierarchy Node. The property name can include dot notation to specify ancestor or child items. Supported: children[<child name>] for children, parent[<level>] or ancestor[<level] for an ancestor at a specific level, or parent[<level>].children[<child name>] or ancestor[<level>].children[<child name>] for a child of an ancestor at a specific level.

        :param property_name: The property_name of this ColumnRuleEventAssetCreatorInputV1.
        :type: str
        """
        if property_name is None:
            raise ValueError("Invalid value for `property_name`, must not be `None`")

        self._property_name = property_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleEventAssetCreatorInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SignalMonitorOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'creator': 'IdentityPreviewV1',
        'cron_schedule': 'list[str]',
        'description': 'str',
        'effective_permissions': 'PermissionsV1',
        'enabled': 'bool',
        'executor_id': 'str',
        'first_run_look_back': 'int',
        'frequency': 'str',
        'id': 'str',
        'is_archived': 'bool',
        'is_redacted': 'bool',
        'last_run_at': 'str',
        'name': 'str',
        'query_range_look_ahead': 'int',
        'sample_event_types': 'list[str]',
        'scoped_to': 'str',
        'signal_ids': 'list[str]',
        'status_message': 'str',
        'translation_key': 'str',
        'type': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'creator': 'creator',
        'cron_schedule': 'cronSchedule',
        'description': 'description',
        'effective_permissions': 'effectivePermissions',
        'enabled': 'enabled',
        'executor_id': 'executorId',
        'first_run_look_back': 'firstRunLookBack',
        'frequency': 'frequency',
        'id': 'id',
        'is_archived': 'isArchived',
        'is_redacted': 'isRedacted',
        'last_run_at': 'lastRunAt',
        'name': 'name',
        'query_range_look_ahead': 'queryRangeLookAhead',
        'sample_event_types': 'sampleEventTypes',
        'scoped_to': 'scopedTo',
        'signal_ids': 'signalIds',
        'status_message': 'statusMessage',
        'translation_key': 'translationKey',
        'type': 'type',
        'updated_at': 'updatedAt'
    }

    def __init__(self, created_at=None, creator=None, cron_schedule=None, description=None, effective_permissions=None, enabled=None, executor_id=None, first_run_look_back=None, frequency=None, id=None, is_archived=False, is_redacted=False, last_run_at=None, name=None, query_range_look_ahead=None, sample_event_types=None, scoped_to=None, signal_ids=None, status_message=None, translation_key=None, type=None, updated_at=None):
        """
        SignalMonitorOutputV1 - a model defined in Swagger
        """

        self._created_at = None
        self._creator = None
        self._cron_schedule = None
        self._description = None
        self._effective_permissions = None
        self._enabled = None
        self._executor_id = None
        self._first_run_look_back = None
        self._frequency = None
        self._id = None
        self._is_archived = None
        self._is_redacted = None
        self._last_run_at = None
        self._name = None
        self._query_range_look_ahead = None
        self._sample_event_types = None
        self._scoped_to = None
        self._signal_ids = None
        self._status_message = None
        self._translation_key = None
        self._type = None
        self._updated_at = None

        if created_at is not None:
          self.created_at = created_at
        if creator is not None:
          self.creator = creator
        if cron_schedule is not None:
          self.cron_schedule = cron_schedule
        if description is not None:
          self.description = description
        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if enabled is not None:
          self.enabled = enabled
        if executor_id is not None:
          self.executor_id = executor_id
        if first_run_look_back is not None:
          self.first_run_look_back = first_run_look_back
        if frequency is not None:
          self.frequency = frequency
        if id is not None:
          self.id = id
        if is_archived is not None:
          self.is_archived = is_archived
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if last_run_at is not None:
          self.last_run_at = last_run_at
        if name is not None:
          self.name = name
        if query_range_look_ahead is not None:
          self.query_range_look_ahead = query_range_look_ahead
        if sample_event_types is not None:
          self.sample_event_types = sample_event_types
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if signal_ids is not None:
          self.signal_ids = signal_ids
        if status_message is not None:
          self.status_message = status_message
        if translation_key is not None:
          self.translation_key = translation_key
        if type is not None:
          self.type = type
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def created_at(self):
        """
        Gets the created_at of this SignalMonitorOutputV1.
        The time the signal monitor was created

        :return: The created_at of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this SignalMonitorOutputV1.
        The time the signal monitor was created

        :param created_at: The created_at of this SignalMonitorOutputV1.
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")

        self._created_at = created_at

    @property
    def creator(self):
        """
        Gets the creator of this SignalMonitorOutputV1.

        :return: The creator of this SignalMonitorOutputV1.
        :rtype: IdentityPreviewV1
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """
        Sets the creator of this SignalMonitorOutputV1.

        :param creator: The creator of this SignalMonitorOutputV1.
        :type: IdentityPreviewV1
        """

        self._creator = creator

    @property
    def cron_schedule(self):
        """
        Gets the cron_schedule of this SignalMonitorOutputV1.
        The signal monitor's check interval(s) as a list of cron expressions (see https://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :return: The cron_schedule of this SignalMonitorOutputV1.
        :rtype: list[str]
        """
        return self._cron_schedule

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule):
        """
        Sets the cron_schedule of this SignalMonitorOutputV1.
        The signal monitor's check interval(s) as a list of cron expressions (see https://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :param cron_schedule: The cron_schedule of this SignalMonitorOutputV1.
        :type: list[str]
        """

        self._cron_schedule = cron_schedule

    @property
    def description(self):
        """
        Gets the description of this SignalMonitorOutputV1.
        Clarifying information or other plain language description of this item

        :return: The description of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SignalMonitorOutputV1.
        Clarifying information or other plain language description of this item

        :param description: The description of this SignalMonitorOutputV1.
        :type: str
        """

        self._description = description

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this SignalMonitorOutputV1.

        :return: The effective_permissions of this SignalMonitorOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this SignalMonitorOutputV1.

        :param effective_permissions: The effective_permissions of this SignalMonitorOutputV1.
        :type: PermissionsV1
        """

        self._effective_permissions = effective_permissions

    @property
    def enabled(self):
        """
        Gets the enabled of this SignalMonitorOutputV1.
        Whether this signal monitor is enabled or not

        :return: The enabled of this SignalMonitorOutputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this SignalMonitorOutputV1.
        Whether this signal monitor is enabled or not

        :param enabled: The enabled of this SignalMonitorOutputV1.
        :type: bool
        """
        if enabled is None:
            raise ValueError("Invalid value for `enabled`, must not be `None`")

        self._enabled = enabled

    @property
    def executor_id(self):
        """
        Gets the executor_id of this SignalMonitorOutputV1.
        ID of the monitor's creator

        :return: The executor_id of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._executor_id

    @executor_id.setter
    def executor_id(self, executor_id):
        """
        Sets the executor_id of this SignalMonitorOutputV1.
        ID of the monitor's creator

        :param executor_id: The executor_id of this SignalMonitorOutputV1.
        :type: str
        """
        if executor_id is None:
            raise ValueError("Invalid value for `executor_id`, must not be `None`")

        self._executor_id = executor_id

    @property
    def first_run_look_back(self):
        """
        Gets the first_run_look_back of this SignalMonitorOutputV1.
        On first run, how far to look back for samples, in seconds

        :return: The first_run_look_back of this SignalMonitorOutputV1.
        :rtype: int
        """
        return self._first_run_look_back

    @first_run_look_back.setter
    def first_run_look_back(self, first_run_look_back):
        """
        Sets the first_run_look_back of this SignalMonitorOutputV1.
        On first run, how far to look back for samples, in seconds

        :param first_run_look_back: The first_run_look_back of this SignalMonitorOutputV1.
        :type: int
        """

        self._first_run_look_back = first_run_look_back

    @property
    def frequency(self):
        """
        Gets the frequency of this SignalMonitorOutputV1.
        The minimum time between monitor runs, in minutes.

        :return: The frequency of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """
        Sets the frequency of this SignalMonitorOutputV1.
        The minimum time between monitor runs, in minutes.

        :param frequency: The frequency of this SignalMonitorOutputV1.
        :type: str
        """

        self._frequency = frequency

    @property
    def id(self):
        """
        Gets the id of this SignalMonitorOutputV1.
        The ID that can be used to interact with the item

        :return: The id of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SignalMonitorOutputV1.
        The ID that can be used to interact with the item

        :param id: The id of this SignalMonitorOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this SignalMonitorOutputV1.
        Whether item is archived

        :return: The is_archived of this SignalMonitorOutputV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this SignalMonitorOutputV1.
        Whether item is archived

        :param is_archived: The is_archived of this SignalMonitorOutputV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this SignalMonitorOutputV1.
        Whether item is redacted

        :return: The is_redacted of this SignalMonitorOutputV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this SignalMonitorOutputV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this SignalMonitorOutputV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def last_run_at(self):
        """
        Gets the last_run_at of this SignalMonitorOutputV1.
        The last time the signal monitor job was run

        :return: The last_run_at of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._last_run_at

    @last_run_at.setter
    def last_run_at(self, last_run_at):
        """
        Sets the last_run_at of this SignalMonitorOutputV1.
        The last time the signal monitor job was run

        :param last_run_at: The last_run_at of this SignalMonitorOutputV1.
        :type: str
        """

        self._last_run_at = last_run_at

    @property
    def name(self):
        """
        Gets the name of this SignalMonitorOutputV1.
        The human readable name

        :return: The name of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SignalMonitorOutputV1.
        The human readable name

        :param name: The name of this SignalMonitorOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def query_range_look_ahead(self):
        """
        Gets the query_range_look_ahead of this SignalMonitorOutputV1.
        Query range look ahead in seconds

        :return: The query_range_look_ahead of this SignalMonitorOutputV1.
        :rtype: int
        """
        return self._query_range_look_ahead

    @query_range_look_ahead.setter
    def query_range_look_ahead(self, query_range_look_ahead):
        """
        Sets the query_range_look_ahead of this SignalMonitorOutputV1.
        Query range look ahead in seconds

        :param query_range_look_ahead: The query_range_look_ahead of this SignalMonitorOutputV1.
        :type: int
        """
        if query_range_look_ahead is None:
            raise ValueError("Invalid value for `query_range_look_ahead`, must not be `None`")

        self._query_range_look_ahead = query_range_look_ahead

    @property
    def sample_event_types(self):
        """
        Gets the sample_event_types of this SignalMonitorOutputV1.
        The list of sample event types to detect. The list can contain one or more of the following values: NEW, BECAME_CERTAIN, STILL_UNCERTAIN, EXTINCT

        :return: The sample_event_types of this SignalMonitorOutputV1.
        :rtype: list[str]
        """
        return self._sample_event_types

    @sample_event_types.setter
    def sample_event_types(self, sample_event_types):
        """
        Sets the sample_event_types of this SignalMonitorOutputV1.
        The list of sample event types to detect. The list can contain one or more of the following values: NEW, BECAME_CERTAIN, STILL_UNCERTAIN, EXTINCT

        :param sample_event_types: The sample_event_types of this SignalMonitorOutputV1.
        :type: list[str]
        """
        if sample_event_types is None:
            raise ValueError("Invalid value for `sample_event_types`, must not be `None`")

        self._sample_event_types = sample_event_types

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this SignalMonitorOutputV1.
        The ID of the workbook to which this item is scoped or null if it is in the global scope.

        :return: The scoped_to of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this SignalMonitorOutputV1.
        The ID of the workbook to which this item is scoped or null if it is in the global scope.

        :param scoped_to: The scoped_to of this SignalMonitorOutputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def signal_ids(self):
        """
        Gets the signal_ids of this SignalMonitorOutputV1.
        The IDs of the monitored signals

        :return: The signal_ids of this SignalMonitorOutputV1.
        :rtype: list[str]
        """
        return self._signal_ids

    @signal_ids.setter
    def signal_ids(self, signal_ids):
        """
        Sets the signal_ids of this SignalMonitorOutputV1.
        The IDs of the monitored signals

        :param signal_ids: The signal_ids of this SignalMonitorOutputV1.
        :type: list[str]
        """
        if signal_ids is None:
            raise ValueError("Invalid value for `signal_ids`, must not be `None`")

        self._signal_ids = signal_ids

    @property
    def status_message(self):
        """
        Gets the status_message of this SignalMonitorOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :return: The status_message of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this SignalMonitorOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :param status_message: The status_message of this SignalMonitorOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def translation_key(self):
        """
        Gets the translation_key of this SignalMonitorOutputV1.
        The item's translation key, if any

        :return: The translation_key of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """
        Sets the translation_key of this SignalMonitorOutputV1.
        The item's translation key, if any

        :param translation_key: The translation_key of this SignalMonitorOutputV1.
        :type: str
        """

        self._translation_key = translation_key

    @property
    def type(self):
        """
        Gets the type of this SignalMonitorOutputV1.
        The type of the item

        :return: The type of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this SignalMonitorOutputV1.
        The type of the item

        :param type: The type of this SignalMonitorOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def updated_at(self):
        """
        Gets the updated_at of this SignalMonitorOutputV1.
        The last time the signal monitor was updated

        :return: The updated_at of this SignalMonitorOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this SignalMonitorOutputV1.
        The last time the signal monitor was updated

        :param updated_at: The updated_at of this SignalMonitorOutputV1.
        :type: str
        """
        if updated_at is None:
            raise ValueError("Invalid value for `updated_at`, must not be `None`")

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SignalMonitorOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
